@@ -1,7 +1,7 @@
 /* Solve linear programming problems by either vertex/point enumeration
    or the primal simplex algorithm.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -20,7 +20,7 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 #include <ppl-config.h>
 #include "ppl_c.h"
@@ -96,6 +96,7 @@ static const char* ppl_source_version = PPL_VERSION;
 #endif
 
 #if defined(PPL_HAVE_SYS_RESOURCE_H) \
+  && PPL_CXX_SUPPORTS_LIMITING_MEMORY \
   && (defined(SA_ONESHOT) || defined(SA_RESETHAND))
 # define PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME
 #endif
@@ -325,7 +326,7 @@ process_options(int argc, char* argv[]) {
       my_exit(0);
       break;
 
-#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+#ifdef PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME
 
     case 'C':
       l = strtol(optarg, &endptr, 10);
@@ -473,17 +474,17 @@ print_clock(FILE* f) {
     time_t saved_secs = saved_ru_utime.tv_sec;
     time_t saved_usecs = saved_ru_utime.tv_usec;
     int secs;
-    int hsecs;
+    int csecs;
     if (current_usecs < saved_usecs) {
-      hsecs = (((1000000 + current_usecs) - saved_usecs) + 5000) / 10000;
+      csecs = (((1000000 + current_usecs) - saved_usecs) + 5000) / 10000;
       secs = (current_secs - saved_secs) -1;
     }
     else {
-      hsecs = ((current_usecs - saved_usecs) + 5000) / 10000;
+      csecs = ((current_usecs - saved_usecs) + 5000) / 10000;
       secs = current_secs - saved_secs;
     }
-    assert(hsecs >= 0 && hsecs < 100 && secs >= 0);
-    fprintf(f, "%d.%.2d", secs, hsecs);
+    assert(csecs >= 0 && csecs < 100 && secs >= 0);
+    fprintf(f, "%d.%.2d", secs, csecs);
   }
 }
 
@@ -524,7 +525,7 @@ set_alarm_on_cpu_time(unsigned seconds, void (*handler)(int)) {
 
 #endif /* defined(PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME) */
 
-#if PPL_HAVE_DECL_RLIMIT_AS
+#if PPL_CXX_SUPPORTS_LIMITING_MEMORY && PPL_HAVE_DECL_RLIMIT_AS
 
 void
 limit_virtual_memory(unsigned long bytes) {
@@ -761,7 +762,7 @@ add_constraints(ppl_Linear_Expression_t ppl_le,
     ppl_delete_Constraint(ppl_c);
     break;
 
- default:
+  default:
     fatal("internal error");
     break;
   }
@@ -1000,9 +1001,10 @@ solve_with_simplex(ppl_const_Constraint_System_t cs,
   return optimum_found;
 }
 
+extern void set_d_eps(mpq_t x, double val);
+
 static void
 set_mpq_t_from_double(mpq_t q, double d) {
-  void set_d_eps(mpq_t x, double val);
   if (check_results)
     set_d_eps(q, d);
   else
