@@ -1,5 +1,6 @@
 /* PPL Java interface common routines implementation.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -18,7 +19,7 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl_java_common.defs.hh"
 
@@ -301,34 +302,26 @@ handle_exception(JNIEnv* env) {
   CHECK_RESULT_ABORT(env, ret == 0);
 }
 
-#ifdef PPL_WATCHDOG_LIBRARY_ENABLED
-
-Parma_Watchdog_Library::Watchdog* p_timeout_object = 0;
+Parma_Polyhedra_Library::Watchdog* p_timeout_object = 0;
 
 Weightwatch* p_deterministic_timeout_object = 0;
 
-#endif // PPL_WATCHDOG_LIBRARY_ENABLED
-
 void
 reset_timeout() {
-#ifdef PPL_WATCHDOG_LIBRARY_ENABLED
   if (p_timeout_object) {
     delete p_timeout_object;
     p_timeout_object = 0;
     abandon_expensive_computations = 0;
   }
-#endif // PPL_WATCHDOG_LIBRARY_ENABLED
 }
 
 void
 reset_deterministic_timeout() {
-#ifdef PPL_WATCHDOG_LIBRARY_ENABLED
   if (p_deterministic_timeout_object) {
     delete p_deterministic_timeout_object;
     p_deterministic_timeout_object = 0;
     abandon_expensive_computations = 0;
   }
-#endif // PPL_WATCHDOG_LIBRARY_ENABLED
 }
 
 jobject
@@ -500,8 +493,7 @@ build_cxx_bounded_overflow(JNIEnv* env, jobject j_bounded_overflow) {
   case 2:
     return OVERFLOW_IMPOSSIBLE;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -516,8 +508,7 @@ build_cxx_bounded_rep(JNIEnv* env, jobject j_bounded_rep) {
   case 1:
     return SIGNED_2_COMPLEMENT;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -538,8 +529,7 @@ build_cxx_bounded_width(JNIEnv* env, jobject j_bounded_width) {
   case 4:
     return BITS_128;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -560,8 +550,7 @@ build_cxx_relsym(JNIEnv* env, jobject j_relsym) {
   case 4:
     return GREATER_THAN;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -576,8 +565,7 @@ build_cxx_optimization_mode(JNIEnv* env, jobject j_opt_mode) {
   case 1:
     return MAXIMIZATION;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -595,8 +583,7 @@ build_java_mip_status(JNIEnv* env, const MIP_Problem_Status& mip_status) {
     fID = cached_FMIDs.MIP_Problem_Status_OPTIMIZED_MIP_PROBLEM_ID;
     break;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_UNREACHABLE;
   }
   return env->GetStaticObjectField(cached_classes.MIP_Problem_Status, fID);
 }
@@ -612,8 +599,7 @@ build_java_pip_status(JNIEnv* env, const PIP_Problem_Status& pip_status) {
     fID = cached_FMIDs.PIP_Problem_Status_OPTIMIZED_PIP_PROBLEM_ID;
     break;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_UNREACHABLE;
   }
   return env->GetStaticObjectField(cached_classes.PIP_Problem_Status, fID);
 }
@@ -629,8 +615,7 @@ build_java_optimization_mode(JNIEnv* env, const Optimization_Mode& opt_mode) {
     fID = cached_FMIDs.Optimization_Mode_MAXIMIZATION_ID;
     break;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_UNREACHABLE;
   }
   return env->GetStaticObjectField(cached_classes.Optimization_Mode, fID);
 }
@@ -644,13 +629,10 @@ build_cxx_control_parameter_name(JNIEnv* env, jobject j_cp_name) {
   CHECK_RESULT_ASSERT(env, cp_name_ordinal_id);
   jint cp_name = env->CallIntMethod(j_cp_name, cp_name_ordinal_id);
   CHECK_EXCEPTION_ASSERT(env);
-  switch (cp_name) {
-  case 0:
+  if (cp_name == 0)
     return MIP_Problem::PRICING;
-  default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
-  }
+  else
+    PPL_JAVA_UNEXPECTED;
 }
 
 jobject
@@ -663,14 +645,11 @@ build_java_control_parameter_name
     = env->GetStaticFieldID(j_cp_name_class, "PRICING",
 			    "Lparma_polyhedra_library/Control_Parameter_Name;");
   CHECK_RESULT_ASSERT(env, cp_name_pricing_get_id);
-  switch (cp_name) {
-  case MIP_Problem::PRICING:
+  if (cp_name == MIP_Problem::PRICING)
     return env->GetStaticObjectField(j_cp_name_class,
 				     cp_name_pricing_get_id);
-  default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
-  }
+  else
+    PPL_UNREACHABLE;
 }
 
 MIP_Problem::Control_Parameter_Value
@@ -690,8 +669,7 @@ build_cxx_control_parameter_value(JNIEnv* env, jobject j_cp_value) {
   case 2:
     return MIP_Problem::PRICING_TEXTBOOK;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -713,8 +691,7 @@ build_java_control_parameter_value
     field_name = "PRICING_TEXTBOOK";
     break;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_UNREACHABLE;
   }
   jfieldID fID = env->GetStaticFieldID(j_cp_value_class, field_name,
                                        "Lparma_polyhedra_library/Control_Parameter_Value;");
@@ -737,13 +714,12 @@ build_cxx_pip_problem_control_parameter_name(JNIEnv* env, jobject j_cp_name) {
   case 1:
     return PIP_Problem::PIVOT_ROW_STRATEGY;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
 jobject
-build_pip_problem_java_control_parameter_name
+build_java_pip_problem_control_parameter_name
 (JNIEnv* env, const PIP_Problem::Control_Parameter_Name& cp_name) {
   jclass j_cp_name_class
     = env->FindClass("parma_polyhedra_library/PIP_Problem_Control_Parameter_Name");
@@ -764,8 +740,7 @@ build_pip_problem_java_control_parameter_name
     return env->GetStaticObjectField(j_cp_name_class,
 				     cp_name_pivot_row_strategy_get_id);
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_UNREACHABLE;
   }
 }
 
@@ -790,8 +765,7 @@ build_cxx_pip_problem_control_parameter_value(JNIEnv* env, jobject j_cp_value) {
   case 4:
     return PIP_Problem::PIVOT_ROW_STRATEGY_MAX_COLUMN;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -819,8 +793,7 @@ build_java_pip_problem_control_parameter_value
     field_name = "PIVOT_ROW_STRATEGY_MAX_COLUMN";
     break;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_UNREACHABLE;
   }
   jfieldID fID = env->GetStaticFieldID(j_cp_value_class, field_name,
                                        "Lparma_polyhedra_library/PIP_Problem_Control_Parameter_Value;");
@@ -853,8 +826,7 @@ build_cxx_constraint(JNIEnv* env, jobject j_constraint) {
   case 4:
     return Constraint(first_le > second_le);
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -913,8 +885,8 @@ build_cxx_linear_expression(JNIEnv* env, jobject j_le) {
     jobject le_value = env->GetObjectField(j_le, fID);
     return -build_cxx_linear_expression(env, le_value);
   }
-  assert(false);
-  throw std::runtime_error("PPL Java interface internal error");
+  // All cases dealt with above.
+  PPL_JAVA_UNEXPECTED;
 }
 
 Generator
@@ -947,8 +919,7 @@ build_cxx_generator(JNIEnv* env, jobject j_generator) {
                            build_cxx_coeff(env, j_div));
     }
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -980,8 +951,7 @@ build_cxx_grid_generator(JNIEnv* env, jobject j_grid_generator) {
                         build_cxx_coeff(env, j_div));
     }
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -1016,9 +986,7 @@ set_pair_element(JNIEnv* env, jobject dst_pair, int arg, jobject src) {
     env->SetObjectField(dst_pair, cached_FMIDs.Pair_second_ID, src);
     break;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error: "
-                             "pair value not allowed");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -1030,9 +998,7 @@ get_pair_element(JNIEnv* env, int arg, jobject j_pair) {
   case 1:
     return env->GetObjectField(j_pair, cached_FMIDs.Pair_second_ID);
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error: "
-                             "pair value not allowed");
+    PPL_JAVA_UNEXPECTED;
   }
 }
 
@@ -1053,8 +1019,7 @@ build_java_constraint(JNIEnv* env, const Constraint& c) {
     fID = cached_FMIDs.Relation_Symbol_GREATER_THAN_ID;
     break;
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_UNREACHABLE;
   }
   jobject relation
     = env->GetStaticObjectField(cached_classes.Relation_Symbol, fID);
@@ -1112,8 +1077,7 @@ build_java_generator(JNIEnv* env, const Generator& g) {
       break;
     }
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_UNREACHABLE;
   }
   CHECK_EXCEPTION_THROW(env);
   return ret;
@@ -1148,8 +1112,7 @@ build_java_grid_generator(JNIEnv* env, const Grid_Generator& g) {
       break;
     }
   default:
-    assert(false);
-    throw std::runtime_error("PPL Java interface internal error");
+    PPL_UNREACHABLE;
   }
   CHECK_EXCEPTION_THROW(env);
   return ret;
