@@ -1,6 +1,6 @@
 /* PPL Java interface: domain-independent functions.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,7 +19,7 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl_java_common.defs.hh"
 #include "parma_polyhedra_library_Artificial_Parameter.h"
@@ -735,7 +735,17 @@ Java_parma_1polyhedra_1library_Parma_1Polyhedra_1Library_version_1beta
 JNIEXPORT jstring JNICALL
 Java_parma_1polyhedra_1library_Parma_1Polyhedra_1Library_version
 (JNIEnv* env, jclass) {
+#if defined(__sun) || defined(__sun__)
+
+  // Some versions of Solaris declare a version() function that causes
+  // the following function call to be ambiguous.
+  return env->NewStringUTF(Parma_Polyhedra_Library::version());
+
+#else // !(defined(__sun) || defined(__sun__))
+
   return env->NewStringUTF(version());
+
+#endif // !(defined(__sun) || defined(__sun__))
 }
 
 JNIEXPORT jstring JNICALL
@@ -784,24 +794,17 @@ Java_parma_1polyhedra_1library_Parma_1Polyhedra_1Library_set_1irrational_1precis
 
 JNIEXPORT void JNICALL
 Java_parma_1polyhedra_1library_Parma_1Polyhedra_1Library_set_1timeout
-(JNIEnv* env, jclass, jint hsecs) {
+(JNIEnv* env, jclass, jint csecs) {
   try {
-#ifndef PPL_WATCHDOG_LIBRARY_ENABLED
-    const char* what = "PPL Java interface error:\n"
-      "Parma_Polyhedra_Library::set_timeout: "
-      "the PPL Watchdog library is not enabled.";
-    throw std::runtime_error(what);
-#else
     // In case a timeout was already set.
     reset_timeout();
-    assert(hsecs > 0);
-    unsigned cxx_hsecs = jtype_to_unsigned<unsigned>(hsecs);
-    assert(cxx_hsecs > 0);
+    assert(csecs > 0);
+    unsigned cxx_csecs = jtype_to_unsigned<unsigned>(csecs);
+    assert(cxx_csecs > 0);
     static timeout_exception e;
-    using Parma_Watchdog_Library::Watchdog;
+    using Parma_Polyhedra_Library::Watchdog;
     p_timeout_object
-      = new Watchdog(cxx_hsecs, abandon_expensive_computations, e);
-#endif // PPL_WATCHDOG_LIBRARY_ENABLED
+      = new Watchdog(cxx_csecs, abandon_expensive_computations, e);
   }
   CATCH_ALL;
 }
@@ -810,37 +813,27 @@ JNIEXPORT void JNICALL
 Java_parma_1polyhedra_1library_Parma_1Polyhedra_1Library_reset_1timeout
 (JNIEnv* env, jclass) {
   try {
-#ifndef PPL_WATCHDOG_LIBRARY_ENABLED
-    const char* what = "PPL Java interface error:\n"
-      "Parma_Polyhedra_Library.reset_timeout(): "
-      "the PPL Watchdog library is not enabled.";
-    throw std::runtime_error(what);
-#else
     reset_timeout();
-#endif // PPL_WATCHDOG_LIBRARY_ENABLED
   }
   CATCH_ALL;
 }
 
 JNIEXPORT void JNICALL
 Java_parma_1polyhedra_1library_Parma_1Polyhedra_1Library_set_1deterministic_1timeout
-(JNIEnv* env, jclass, jint weight) {
+(JNIEnv* env, jclass, jint unscaled_weight, jint scale) {
   try {
-#ifndef PPL_WATCHDOG_LIBRARY_ENABLED
-    const char* what = "PPL Java interface error:\n"
-      "Parma_Polyhedra_Library::set_deterministic_timeout: "
-      "the PPL Watchdog library is not enabled.";
-    throw std::runtime_error(what);
-#else
     // In case a timeout was already set.
     reset_deterministic_timeout();
-    assert(weight > 0);
-    unsigned cxx_weight = jtype_to_unsigned<unsigned>(weight);
-    assert(cxx_weight > 0);
+    // Note: let `unscaled_weight == 0' result in an exception.
+    assert(unscaled_weight >= 0 && scale >= 0);
+    unsigned long cxx_unscaled_weight
+      = jtype_to_unsigned<unsigned long>(unscaled_weight);
+    unsigned cxx_scale = jtype_to_unsigned<unsigned>(scale);
     static deterministic_timeout_exception e;
+    typedef Parma_Polyhedra_Library::Weightwatch_Traits Traits;
     p_deterministic_timeout_object
-      = new Weightwatch(cxx_weight, abandon_expensive_computations, e);
-#endif // PPL_WATCHDOG_LIBRARY_ENABLED
+      = new Weightwatch(Traits::compute_delta(cxx_unscaled_weight, cxx_scale),
+                        abandon_expensive_computations, e);
   }
   CATCH_ALL;
 }
@@ -849,14 +842,7 @@ JNIEXPORT void JNICALL
 Java_parma_1polyhedra_1library_Parma_1Polyhedra_1Library_reset_1deterministic_1timeout
 (JNIEnv* env, jclass) {
   try {
-#ifndef PPL_WATCHDOG_LIBRARY_ENABLED
-    const char* what = "PPL Java interface error:\n"
-      "Parma_Polyhedra_Library.reset_deterministic_timeout(): "
-      "the PPL Watchdog library is not enabled.";
-    throw std::runtime_error(what);
-#else
     reset_deterministic_timeout();
-#endif // PPL_WATCHDOG_LIBRARY_ENABLED
   }
   CATCH_ALL;
 }
