@@ -195,7 +195,7 @@ external ppl_reset_timeout:
 unit -> unit = "ppl_reset_timeout"
 
 external ppl_set_deterministic_timeout:
-int -> unit = "ppl_set_deterministic_timeout"
+int -> int -> unit = "ppl_set_deterministic_timeout"
 
 external ppl_reset_deterministic_timeout:
 unit -> unit = "ppl_reset_deterministic_timeout"
