@@ -1,6 +1,6 @@
 % Extra test code for the generated tests for the Prolog interfaces.
 % Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-% Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+% Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 %
 % This file is part of the Parma Polyhedra Library (PPL).
 %
@@ -19,7 +19,7 @@
 % Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 %
 % For the most up-to-date information see the Parma Polyhedra Library
-% site: http://www.cs.unipr.it/ppl/ .
+% site: http://bugseng.com/products/ppl/ .
 
 :- dynamic(noisy/1).
 
