@@ -1,6 +1,6 @@
 /* Constraint_System class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,10 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Constraint_System.defs.hh"
 #include "Constraint_System.inlines.hh"
 #include "Generator.defs.hh"
@@ -100,6 +99,7 @@ adjust_topology_and_space_dimension(const Topology new_topology,
   }
 
   // Here the constraint system is not empty.
+  using std::swap;
   if (cols_to_be_added > 0)
     if (old_topology != new_topology)
       if (new_topology == NECESSARILY_CLOSED) {
@@ -116,7 +116,8 @@ adjust_topology_and_space_dimension(const Topology new_topology,
 	// we just decrement the number of columns to be added.
 	Constraint_System& cs = *this;
 	const dimension_type eps_index = old_space_dim + 1;
-	dimension_type cs_num_rows = cs.num_rows();
+        const dimension_type old_cs_num_rows = cs.num_rows();
+        dimension_type cs_num_rows = old_cs_num_rows;
 	bool was_sorted = cs.is_sorted();
 	if (was_sorted)
 	  cs.set_sorted(false);
@@ -127,9 +128,9 @@ adjust_topology_and_space_dimension(const Topology new_topology,
 	  for (dimension_type i = cs_num_rows; i-- > 0; )
 	    if (cs[i][eps_index] != 0) {
 	      --cs_num_rows;
-	      std::swap(cs[i], cs[cs_num_rows]);
+	      swap(cs[i], cs[cs_num_rows]);
 	    }
-	  cs.erase_to_end(cs_num_rows);
+	  cs.remove_trailing_rows(old_cs_num_rows - cs_num_rows);
 	  cs.unset_pending_rows();
 	}
 	else {
@@ -142,22 +143,22 @@ adjust_topology_and_space_dimension(const Topology new_topology,
 	  for (dimension_type i = new_first_pending; i-- > 0; )
 	    if (cs[i][eps_index] != 0) {
 	      --new_first_pending;
-	      std::swap(cs[i], cs[new_first_pending]);
+	      swap(cs[i], cs[new_first_pending]);
 	    }
 	  const dimension_type num_swaps
 	    = old_first_pending - new_first_pending;
           cs.set_index_first_pending_row(new_first_pending);
 	  // Move the swapped rows to the real end of the matrix.
 	  for (dimension_type i = num_swaps; i-- > 0; )
-	    std::swap(cs[old_first_pending - i], cs[cs_num_rows - i]);
+	    swap(cs[old_first_pending - i], cs[cs_num_rows - i]);
 	  cs_num_rows -= num_swaps;
 	  // Now iterate through the pending rows.
 	  for (dimension_type i = cs_num_rows; i-- > new_first_pending; )
 	    if (cs[i][eps_index] != 0) {
 	      --cs_num_rows;
-	      std::swap(cs[i], cs[cs_num_rows]);
+	      swap(cs[i], cs[cs_num_rows]);
 	    }
-	  cs.erase_to_end(cs_num_rows);
+	  cs.remove_trailing_rows(old_cs_num_rows - cs_num_rows);
 	}
 
 	// If `cs' was sorted we sort it again.
