@@ -1,6 +1,6 @@
 /* Generator class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,12 +19,10 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Generator.defs.hh"
-
 #include "Variable.defs.hh"
 #include <iostream>
 #include <sstream>
@@ -34,12 +32,12 @@ namespace PPL = Parma_Polyhedra_Library;
 
 void
 PPL::Generator::throw_dimension_incompatible(const char* method,
-					     const char* name_var,
+					     const char* v_name,
 					     const Variable v) const {
   std::ostringstream s;
   s << "PPL::Generator::" << method << ":" << std::endl
     << "this->space_dimension() == " << space_dimension() << ", "
-    << name_var << ".space_dimension() == " << v.space_dimension() << ".";
+    << v_name << ".space_dimension() == " << v.space_dimension() << ".";
   throw std::invalid_argument(s.str());
 }
 
@@ -217,25 +215,25 @@ PPL::IO_Operators::operator<<(std::ostream& s, const Generator& g) {
     break;
   }
 
-  PPL_DIRTY_TEMP_COEFFICIENT(gv);
+  PPL_DIRTY_TEMP_COEFFICIENT(g_v);
   bool first = true;
   for (dimension_type v = 0; v < num_variables; ++v) {
-    gv = g[v+1];
-    if (gv != 0) {
+    g_v = g[v+1];
+    if (g_v != 0) {
       if (!first) {
-	if (gv > 0)
+	if (g_v > 0)
 	  s << " + ";
 	else {
 	  s << " - ";
-	  neg_assign(gv);
+	  neg_assign(g_v);
 	}
       }
       else
 	first = false;
-      if (gv == -1)
+      if (g_v == -1)
 	s << "-";
-      else if (gv != 1)
-	s << gv << "*";
+      else if (g_v != 1)
+	s << g_v << "*";
       s << PPL::Variable(v);
     }
   }
@@ -322,7 +320,7 @@ PPL::Generator::OK() const {
     return false;
 
   // Topology consistency check.
-  const dimension_type min_size = is_necessarily_closed() ? 1 : 2;
+  const dimension_type min_size = is_necessarily_closed() ? 1U : 2U;
   if (size() < min_size) {
 #ifndef NDEBUG
     std::cerr << "Generator has fewer coefficients than the minimum "
