@@ -1,6 +1,6 @@
 /* Generator_System class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,10 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Generator_System.defs.hh"
 #include "Generator_System.inlines.hh"
 #include "Constraint.defs.hh"
@@ -86,7 +85,7 @@ adjust_topology_and_space_dimension(const Topology new_topology,
     return true;
   }
 
-  // Here the generator systen is not empty.
+  // Here the generator system is not empty.
   if (cols_to_be_added > 0)
     if (old_topology != new_topology)
       if (new_topology == NECESSARILY_CLOSED) {
@@ -106,9 +105,11 @@ adjust_topology_and_space_dimension(const Topology new_topology,
 	for (dimension_type i = 0; i < gs_end; ) {
 	  // All the closure points seen so far have consecutive
 	  // indices starting from `i'.
-	  if (num_closure_points > 0)
+	  if (num_closure_points > 0) {
 	    // Let next generator have index `i'.
-	    std::swap(gs[i], gs[i+num_closure_points]);
+            using std::swap;
+	    swap(gs[i], gs[i+num_closure_points]);
+          }
 	  if (gs[i].is_closure_point()) {
 	    ++num_closure_points;
 	    --gs_end;
@@ -119,7 +120,7 @@ adjust_topology_and_space_dimension(const Topology new_topology,
 	// We may have identified some closure points.
 	if (num_closure_points > 0) {
 	  PPL_ASSERT(num_closure_points == num_rows() - gs_end);
-	  erase_to_end(gs_end);
+	  remove_trailing_rows(num_closure_points);
 	}
 	// Remove the epsilon column, re-normalize and, after that,
 	// add the missing dimensions. This ensures that
@@ -805,7 +806,8 @@ PPL::Generator_System
   for (dimension_type i = n_rows; i-- > 0; ) {
     Generator& row = x[i];
     Scalar_Products::assign(numerator, expr, row);
-    std::swap(numerator, row[v]);
+    using std::swap;
+    swap(numerator, row[v]);
   }
 
   if (denominator != 1) {
@@ -952,15 +954,17 @@ PPL::Generator_System::remove_invalid_lines_and_rays() {
   // NOTE: the following swaps will mix generators without even trying
   // to preserve sortedness: as a matter of fact, it will almost always
   // be the case that the input generator system is NOT sorted.
+  using std::swap;
   Generator_System& gs = *this;
-  dimension_type n_rows = gs.num_rows();
+  const dimension_type old_n_rows = gs.num_rows();
+  dimension_type n_rows = old_n_rows;
   if (num_pending_rows() == 0) {
     for (dimension_type i = n_rows; i-- > 0; ) {
       Generator& g = gs[i];
       if (g.is_line_or_ray() && g.all_homogeneous_terms_are_zero()) {
 	// An invalid line/ray has been found.
 	--n_rows;
-	std::swap(g, gs[n_rows]);
+	swap(g, gs[n_rows]);
 	gs.set_sorted(false);
       }
     }
@@ -981,7 +985,7 @@ PPL::Generator_System::remove_invalid_lines_and_rays() {
       if (g.is_line_or_ray() && g.all_homogeneous_terms_are_zero()) {
 	// An invalid line/ray has been found.
 	--first_pending;
-	std::swap(g, gs[first_pending]);
+	swap(g, gs[first_pending]);
 	gs.set_sorted(false);
       }
     }
@@ -989,19 +993,19 @@ PPL::Generator_System::remove_invalid_lines_and_rays() {
       = first_pending_row() - first_pending;
     set_index_first_pending_row(first_pending);
     for (dimension_type i = 0; i < num_invalid_rows; ++i)
-      std::swap(gs[n_rows - i], gs[first_pending + i]);
+      swap(gs[n_rows - i], gs[first_pending + i]);
     n_rows -= num_invalid_rows;
     for (dimension_type i = n_rows; i-- > first_pending; ) {
       Generator& g = gs[i];
       if (g.is_line_or_ray() && g.all_homogeneous_terms_are_zero()) {
 	// An invalid line/ray has been found.
 	--n_rows;
-	std::swap(g, gs[n_rows]);
+	swap(g, gs[n_rows]);
 	gs.set_sorted(false);
       }
     }
   }
-  gs.erase_to_end(n_rows);
+  gs.remove_trailing_rows(old_n_rows - n_rows);
 }
 
 const PPL::Generator_System* PPL::Generator_System::zero_dim_univ_p = 0;
