@@ -1,6 +1,6 @@
 /* Grid_Generator_System class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,9 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
-#include <ppl-config.h>
+#include "ppl-config.h"
 #include "Grid_Generator_System.defs.hh"
 #include "Grid_Generator_System.inlines.hh"
 #include "Scalar_Products.defs.hh"
@@ -54,7 +54,7 @@ PPL::Grid_Generator_System::recycling_insert(Grid_Generator_System& gs) {
   // of swapping each entire row.  This ensures that the added rows
   // have the same capacities as the existing rows.
   for (dimension_type i = gs_num_rows; i-- > 0; )
-    operator[](old_num_rows + i).coefficient_swap(gs[i]);
+    (*this)[old_num_rows + i].coefficient_swap(gs[i]);
 }
 
 void
@@ -78,15 +78,15 @@ PPL::Grid_Generator_System::recycling_insert(Grid_Generator& g) {
   // Swap one coefficient at a time into the newly added rows, instead
   // of swapping each entire row.  This ensures that the added rows
   // have the same capacities as the existing rows.
-  operator[](old_num_rows).coefficient_swap(g);
+  (*this)[old_num_rows].coefficient_swap(g);
 }
 
 void
 PPL::Grid_Generator_System::insert(const Grid_Generator& g) {
-  dimension_type g_space_dim = g.space_dimension();
 
   if (g.is_parameter())
     if (g.all_homogeneous_terms_are_zero()) {
+      dimension_type g_space_dim = g.space_dimension();
       dimension_type initial_space_dim = space_dimension();
       if (initial_space_dim < g_space_dim) {
 	// Adjust the space dimension.
@@ -134,21 +134,22 @@ PPL::Grid_Generator_System::insert(const Grid_Generator& g) {
 	// Swap the existing parameter divisor column into the new
 	// last column.
 	swap_columns(old_num_columns - 1, g_size - 1);
-      Matrix::add_row(g);
+      Dense_Matrix::add_row(g);
     }
     else if (g_size < old_num_columns)
       if (old_num_rows == 0)
-	Matrix::add_row(Linear_Row(g, old_num_columns, row_capacity));
+	Dense_Matrix::add_row(Linear_Row(g, old_num_columns, row_capacity));
       else {
 	// Create a resized copy of the row (and move the parameter
 	// divisor coefficient to its last position).
 	Linear_Row tmp_row(g, old_num_columns, row_capacity);
-	std::swap(tmp_row[g_size - 1], tmp_row[old_num_columns - 1]);
-	Matrix::add_row(tmp_row);
+        using std::swap;
+	swap(tmp_row[g_size - 1], tmp_row[old_num_columns - 1]);
+	Dense_Matrix::add_row(tmp_row);
       }
     else
       // Here r_size == old_num_columns.
-      Matrix::add_row(g);
+      Dense_Matrix::add_row(g);
 
   } // Generator_System::insert(g) substitute.
 
@@ -181,7 +182,8 @@ PPL::Grid_Generator_System
   for (dimension_type i = num_rows; i-- > 0; ) {
     Grid_Generator& row = x[i];
     Scalar_Products::assign(numerator, expr, row);
-    std::swap(numerator, row[v]);
+    using std::swap;
+    swap(numerator, row[v]);
   }
 
   if (denominator != 1)
@@ -206,10 +208,11 @@ PPL_OUTPUT_DEFINITIONS(Grid_Generator_System)
 
 void
 PPL::Grid_Generator_System::ascii_dump(std::ostream& s) const {
-  const dimension_type num_rows = this->num_rows();
-  s << num_rows << " x " << num_columns() << '\n';
+  const Grid_Generator_System& ggs = *this;
+  const dimension_type num_rows = ggs.num_rows();
+  s << num_rows << " x " << ggs.num_columns() << '\n';
   for (dimension_type i = 0; i < num_rows; ++i)
-    operator[](i).ascii_dump(s);
+    ggs[i].ascii_dump(s);
 }
 
 bool
@@ -318,9 +321,10 @@ PPL::Grid_Generator_System
   // Swap the parameter divisor column into the new last column.
   swap_columns(col, col + dims);
   // Set the diagonal element of each added rows.
-  dimension_type num_rows = this->num_rows();
+  Grid_Generator_System& x = *this;
+  const dimension_type num_rows = x.num_rows();
   for (dimension_type row = num_rows - dims; row < num_rows; ++row, ++col)
-    const_cast<Coefficient&>(operator[](row)[col]) = 1;
+    x[row][col] = 1;
 }
 
 void
@@ -345,16 +349,16 @@ PPL::Grid_Generator_System
     const dimension_type vsi_col = *vsi+1;
     // Move all columns in between to the left.
     while (src_col < vsi_col)
-      Matrix::swap_columns(dst_col++, src_col++);
+      Dense_Matrix::swap_columns(dst_col++, src_col++);
     ++src_col;
   }
   // Move any remaining columns.
   const dimension_type num_columns = this->num_columns();
   while (src_col < num_columns)
-    Matrix::swap_columns(dst_col++, src_col++);
+    Dense_Matrix::swap_columns(dst_col++, src_col++);
 
   // The number of remaining columns is `dst_col'.
-  Matrix::remove_trailing_columns(num_columns - dst_col);
+  Dense_Matrix::remove_trailing_columns(num_columns - dst_col);
 }
 
 void
@@ -373,6 +377,6 @@ PPL::Grid_Generator_System
   // Swap the parameter divisor column into the column that will
   // become the last column.
   swap_columns(new_dimension + 1, space_dim + 1);
-  Matrix::remove_trailing_columns(space_dim - new_dimension);
+  Dense_Matrix::remove_trailing_columns(space_dim - new_dimension);
   PPL_ASSERT(OK());
 }
