@@ -1,7 +1,7 @@
 /* Grid class implementation
    (non-inline private or protected functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -20,10 +20,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Grid.defs.hh"
 #include "Grid_Generator.defs.hh"
 #include "Scalar_Products.defs.hh"
@@ -63,7 +62,7 @@ PPL::Grid::construct(dimension_type num_dimensions,
     // dimension and then store it in `con_sys'.
     Congruence_System cgs(Congruence::zero_dim_false());
     cgs.increase_space_dimension(space_dim);
-    const_cast<Congruence_System&>(con_sys).swap(cgs);
+    con_sys.m_swap(cgs);
 
     PPL_ASSERT(OK());
     return;
@@ -83,7 +82,7 @@ PPL::Grid::construct(dimension_type num_dimensions,
     Congruence_System cgs(Congruence::zero_dim_integrality());
     cgs.increase_space_dimension(space_dim);
     cgs[0][0] = 1; // Recover minimal form after cgs(zdi) normalization.
-    con_sys.swap(cgs);
+    con_sys.m_swap(cgs);
 
     dim_kinds[0] = PROPER_CONGRUENCE /* a.k.a. PARAMETER */;
 
@@ -116,7 +115,7 @@ PPL::Grid::construct(Congruence_System& cgs) {
 
   if (space_dim > 0) {
     // Stealing the rows from `cgs'.
-    std::swap(con_sys, cgs);
+    con_sys.m_swap(cgs);
     con_sys.normalize_moduli();
     set_congruences_up_to_date();
   }
@@ -169,7 +168,7 @@ PPL::Grid::construct(Grid_Generator_System& ggs) {
     set_zero_dim_univ();
   else {
     // Steal the rows from `ggs'.
-    std::swap(gen_sys, ggs);
+    gen_sys.m_swap(ggs);
     normalize_divisors(gen_sys);
     // Generators are now up-to-date.
     set_generators_up_to_date();
@@ -402,7 +401,7 @@ PPL::Grid::max_min(const Linear_Expression& expr,
       ext_n = 0;
       ext_d = 1;
       included = true;
-      if (point)
+      if (point != 0)
 	*point = Generator::point();
       return true;
     }
@@ -425,7 +424,7 @@ PPL::Grid::max_min(const Linear_Expression& expr,
     exact_div_assign(ext_d, ext_d, gcd);
 
     included = true;
-    if (point) {
+    if (point != 0) {
       Linear_Expression e;
       for (dimension_type i = space_dim; i-- > 0; )
 	e += gen.coefficient(Variable(i)) * Variable(i);
@@ -451,13 +450,13 @@ PPL::Grid::set_empty() {
 
   // Replace gen_sys with an empty system of the right dimension.
   Grid_Generator_System gs(space_dim);
-  gen_sys.swap(gs);
+  gen_sys.m_swap(gs);
 
   // Extend the zero dim false congruence system to the appropriate
   // dimension and then swap it with `con_sys'.
   Congruence_System cgs(Congruence::zero_dim_false());
   cgs.increase_space_dimension(space_dim);
-  const_cast<Congruence_System&>(con_sys).swap(cgs);
+  con_sys.m_swap(cgs);
 }
 
 void
@@ -616,7 +615,7 @@ PPL::Grid::normalize_divisors(Grid_Generator_System& sys,
     dimension_type row = 0;
     dimension_type num_rows = sys.num_rows();
 
-    if (first_point)
+    if (first_point != 0)
       lcm_assign(divisor, divisor, (*first_point).divisor());
     else {
       PPL_ASSERT(num_rows > 0);
@@ -705,15 +704,7 @@ PPL::Grid::refine_no_check(const Constraint& c) {
 }
 
 void
-PPL::Grid::throw_runtime_error(const char* method) const {
-  std::ostringstream s;
-  s << "PPL::Grid::" << method << "." << std::endl;
-  throw std::runtime_error(s.str());
-}
-
-void
-PPL::Grid::throw_invalid_argument(const char* method,
-				  const char* reason) const {
+PPL::Grid::throw_invalid_argument(const char* method, const char* reason) {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << reason << ".";
@@ -740,9 +731,9 @@ PPL::Grid::throw_dimension_incompatible(const char* method,
 
 void
 PPL::Grid::throw_dimension_incompatible(const char* method,
-					const char* e_name,
-					const Linear_Expression& e) const {
-  throw_dimension_incompatible(method, e_name, e.space_dimension());
+					const char* le_name,
+					const Linear_Expression& le) const {
+  throw_dimension_incompatible(method, le_name, le.space_dimension());
 }
 
 void
@@ -816,18 +807,9 @@ throw_dimension_incompatible(const char* method,
   throw std::invalid_argument(s.str());
 }
 
-void
-PPL::Grid::throw_space_dimension_overflow(const char* method,
-					  const char* reason) {
-  std::ostringstream s;
-  s << "PPL::Grid::" << method << ":" << std::endl
-    << reason << ".";
-  throw std::length_error(s.str());
-}
-
 void
 PPL::Grid::throw_invalid_constraint(const char* method,
-				    const char* c_name) const {
+				    const char* c_name) {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << c_name << " is not an equality constraint.";
@@ -836,7 +818,7 @@ PPL::Grid::throw_invalid_constraint(const char* method,
 
 void
 PPL::Grid::throw_invalid_constraints(const char* method,
-				    const char* cs_name) const {
+				    const char* cs_name) {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << "the constraint system " << cs_name
@@ -846,7 +828,7 @@ PPL::Grid::throw_invalid_constraints(const char* method,
 
 void
 PPL::Grid::throw_invalid_generator(const char* method,
-				   const char* g_name) const {
+				   const char* g_name) {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << "*this is an empty grid and "
@@ -856,7 +838,7 @@ PPL::Grid::throw_invalid_generator(const char* method,
 
 void
 PPL::Grid::throw_invalid_generators(const char* method,
-				    const char* gs_name) const {
+				    const char* gs_name) {
   std::ostringstream s;
   s << "PPL::Grid::" << method << ":" << std::endl
     << "*this is an empty grid and" << std::endl
