@@ -1,6 +1,6 @@
 /* Grid class implementation (non-inline public functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,12 +19,11 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Grid.defs.hh"
-#include "Topology.hh"
+#include "Topology.types.hh"
 #include "Scalar_Products.defs.hh"
 #include "Polyhedron.defs.hh"
 #include "assert.hh"
@@ -58,12 +57,13 @@ PPL::Grid::Grid(const Grid& y, Complexity_Class)
 }
 
 PPL::Grid::Grid(const Constraint_System& cs)
-  : con_sys(cs.space_dimension() > max_space_dimension()
-	    ? throw_space_dimension_overflow("Grid(cs)",
-					     "the space dimension of cs "
-					     "exceeds the maximum allowed "
-					     "space dimension"), 0
-	    : cs.space_dimension()),
+  : con_sys(check_space_dimension_overflow(cs.space_dimension(),
+                                           max_space_dimension(),
+                                           "PPL::Grid::",
+                                           "Grid(cs)",
+                                           "the space dimension of cs "
+                                           "exceeds the maximum allowed "
+                                           "space dimension")),
     gen_sys(cs.space_dimension()) {
   space_dim = cs.space_dimension();
 
@@ -97,13 +97,14 @@ PPL::Grid::Grid(const Constraint_System& cs)
 }
 
 PPL::Grid::Grid(Constraint_System& cs, Recycle_Input)
- : con_sys(cs.space_dimension() > max_space_dimension()
-	   ? throw_space_dimension_overflow("Grid(cs, recycle)",
-					    "the space dimension of cs "
-					    "exceeds the maximum allowed "
-					    "space dimension"), 0
-	   : cs.space_dimension()),
-   gen_sys(cs.space_dimension()) {
+  : con_sys(check_space_dimension_overflow(cs.space_dimension(),
+                                           max_space_dimension(),
+                                           "PPL::Grid::",
+                                           "Grid(cs, recycle)",
+                                           "the space dimension of cs "
+                                           "exceeds the maximum allowed "
+                                           "space dimension")),
+    gen_sys(cs.space_dimension()) {
   space_dim = cs.space_dimension();
 
   if (space_dim == 0) {
@@ -137,12 +138,13 @@ PPL::Grid::Grid(Constraint_System& cs, Recycle_Input)
 
 PPL::Grid::Grid(const Polyhedron& ph,
                 Complexity_Class complexity)
-  : con_sys(ph.space_dimension() > max_space_dimension()
-	    ? throw_space_dimension_overflow("Grid(ph)",
-					     "the space dimension of ph "
-					     "exceeds the maximum allowed "
-					     "space dimension"), 0
-	    : ph.space_dimension()),
+  : con_sys(check_space_dimension_overflow(ph.space_dimension(),
+                                           max_space_dimension(),
+                                           "PPL::Grid::",
+                                           "Grid(ph)",
+                                           "the space dimension of ph "
+                                           "exceeds the maximum allowed "
+                                           "space dimension")),
     gen_sys(ph.space_dimension()) {
   space_dim = ph.space_dimension();
 
@@ -309,7 +311,7 @@ const PPL::Grid_Generator_System&
 PPL::Grid::grid_generators() const {
   if (space_dim == 0) {
     PPL_ASSERT(gen_sys.space_dimension() == 0
-	   && gen_sys.num_rows() == (marked_empty() ? 0 : 1));
+               && gen_sys.num_rows() == (marked_empty() ? 0U : 1U));
     return gen_sys;
   }
 
@@ -331,7 +333,7 @@ const PPL::Grid_Generator_System&
 PPL::Grid::minimized_grid_generators() const {
   if (space_dim == 0) {
     PPL_ASSERT(gen_sys.space_dimension() == 0
-	   && gen_sys.num_rows() == (marked_empty() ? 0 : 1));
+               && gen_sys.num_rows() == (marked_empty() ? 0U : 1U));
     return gen_sys;
   }
 
@@ -397,87 +399,85 @@ PPL::Grid::relation_with(const Congruence& cg) const {
   PPL_DIRTY_TEMP_COEFFICIENT(point_sp);
   point_sp = 0;
 
-  const Coefficient& modulus = cg.modulus();
-
   PPL_DIRTY_TEMP_COEFFICIENT(div);
-  div = modulus;
+  div = cg.modulus();
 
   PPL_DIRTY_TEMP_COEFFICIENT(sp);
 
   bool known_to_intersect = false;
 
-  for (Grid_Generator_System::const_iterator g = gen_sys.begin(),
-         gen_sys_end = gen_sys.end(); g != gen_sys_end; ++g) {
-    Scalar_Products::assign(sp, cg, *g);
+  for (Grid_Generator_System::const_iterator i = gen_sys.begin(),
+         i_end = gen_sys.end(); i != i_end; ++i) {
+    const Grid_Generator& g = *i;
+    Scalar_Products::assign(sp, cg, g);
 
-    switch (g->type()) {
+    switch (g.type()) {
 
     case Grid_Generator::POINT:
       if (cg.is_proper_congruence())
 	sp %= div;
-      if (sp == 0)
+      if (sp == 0) {
 	// The point satisfies the congruence.
 	if (point_sp == 0)
 	  // Any previous points satisfied the congruence.
 	  known_to_intersect = true;
 	else
 	  return Poly_Con_Relation::strictly_intersects();
-      else
-	if (point_sp == 0) {
-	  if (known_to_intersect)
-	    return Poly_Con_Relation::strictly_intersects();
-	  // Assign `sp' to `point_sp' as `sp' is the scalar product
-	  // of cg and a point g and is non-zero.
-	  point_sp = sp;
+      }
+      else {
+        if (point_sp == 0) {
+          if (known_to_intersect)
+            return Poly_Con_Relation::strictly_intersects();
+          // Assign `sp' to `point_sp' as `sp' is the scalar product
+          // of cg and a point g and is non-zero.
+          point_sp = sp;
 	}
-	else {
-	  // A previously considered point p failed to satisfy cg such that
-	  // `point_sp' = `scalar_prod(p, cg)'
-	  // so, if we consider the parameter g-p instead of g, we have
-	  // scalar_prod(g-p, cg) = scalar_prod(g, cg) - scalar_prod(p, cg)
-	  //                      = sp - point_sp
-	  sp -= point_sp;
+        else {
+          // A previously considered point p failed to satisfy cg such that
+          // `point_sp' = `scalar_prod(p, cg)'
+          // so, if we consider the parameter g-p instead of g, we have
+          // scalar_prod(g-p, cg) = scalar_prod(g, cg) - scalar_prod(p, cg)
+          //                      = sp - point_sp
+          sp -= point_sp;
 
-	  if (sp != 0) {
-	    // Find the GCD between sp and the previous GCD.
-	    gcd_assign(div, div, sp);
-	    if (point_sp % div == 0)
-	      // There is a point in the grid satisfying cg.
-	      return Poly_Con_Relation::strictly_intersects();
-	  }
-	}
+          if (sp != 0) {
+            // Find the GCD between sp and the previous GCD.
+            gcd_assign(div, div, sp);
+            if (point_sp % div == 0)
+              // There is a point in the grid satisfying cg.
+              return Poly_Con_Relation::strictly_intersects();
+          }
+        }
+      }
       break;
 
     case Grid_Generator::PARAMETER:
       if (cg.is_proper_congruence())
-	sp %= (div * g->divisor());
+	sp %= (div * g.divisor());
       if (sp == 0)
 	// Parameter g satisfies the cg so the relation depends
 	// entirely on the other generators.
 	break;
-
       if (known_to_intersect)
-	// At least one point satisfies cg.  However, the sum of such
-	// a point and the parameter g fails to satisfy cg (due to g).
-	return Poly_Con_Relation::strictly_intersects();
-
+        // At least one point satisfies cg.  However, the sum of such
+        // a point and the parameter g fails to satisfy cg (due to g).
+        return Poly_Con_Relation::strictly_intersects();
       // Find the GCD between sp and the previous GCD.
       gcd_assign(div, div, sp);
-      if (point_sp != 0)
-	// At least one of any previously encountered points fails to
-	// satisfy cg.
-	if (point_sp % div == 0)
-	  //////	if (point_sp == div)
-	  // There is also a grid point that satisfies cg.
-	  return Poly_Con_Relation::strictly_intersects();
-
+      if (point_sp != 0) {
+        // At least one of any previously encountered points fails to
+        // satisfy cg.
+        if (point_sp % div == 0)
+          // There is also a grid point that satisfies cg.
+          return Poly_Con_Relation::strictly_intersects();
+      }
       break;
 
     case Grid_Generator::LINE:
       if (sp == 0)
-	// Line g satisfies the cg so the relation depends entirely on
-	// the other generators.
-	break;
+        // Line g satisfies the cg so the relation depends entirely on
+        // the other generators.
+        break;
 
       // Line g intersects the congruence.
       //
@@ -491,7 +491,6 @@ PPL::Grid::relation_with(const Congruence& cg) const {
       // *this that does not satisfy `cg' and hence `p+g' is a point
       // in *this not in the grid defined by `cg'; therefore `*this'
       // strictly intersects the `cg' grid.
-
       return Poly_Con_Relation::strictly_intersects();
     }
   }
@@ -624,53 +623,71 @@ PPL::Grid::relation_with(const Constraint& c) const {
 
   bool point_is_included = false;
   bool point_saturates = false;
-  const Grid_Generator* first_point = NULL;
-
-  for (Grid_Generator_System::const_iterator g = gen_sys.begin(),
-         gen_sys_end = gen_sys.end(); g != gen_sys_end; ++g)
-    switch (g->type()) {
+  const Grid_Generator* first_point = 0;
 
+  for (Grid_Generator_System::const_iterator i = gen_sys.begin(),
+         i_end = gen_sys.end(); i != i_end; ++i) {
+    const Grid_Generator& g = *i;
+    switch (g.type()) {
     case Grid_Generator::POINT:
       {
-	Grid_Generator& gen = const_cast<Grid_Generator&>(*g);
-	if (first_point == NULL) {
-	  first_point = &gen;
-	  const int sign = Scalar_Products::sign(c, gen);
-	  Constraint::Type type = c.type();
-	  if ((type == Constraint::NONSTRICT_INEQUALITY && sign == 0)) {
-	    point_saturates = true;
-	  }
+	if (first_point == 0) {
+	  first_point = &g;
+	  const int sign = Scalar_Products::sign(c, g);
+	  if (sign == 0)
+            point_saturates = !c.is_strict_inequality();
 	  else if (sign > 0)
-	    point_is_included = true;
+            point_is_included = !c.is_equality();
 	  break;
 	}
-	// Else convert g to a parameter, and continue into the
-	// parameter case.
+	// Not the first point: convert `g' to be a parameter
+	// and fall through into the parameter case.
+	Grid_Generator& gen = const_cast<Grid_Generator&>(g);
+	const Grid_Generator& point = *first_point;
+        const Coefficient& p_div = g[0];
+        if (p_div != Coefficient_one()) {
+          for (dimension_type j = gen.size() - 1; j-- > 1; )
+            gen[j] *= p_div;
+        }
+        const Coefficient& g_div = gen[0];
+        if (g_div == Coefficient_one()) {
+          for (dimension_type j = gen.size() - 1; j-- > 1; )
+            gen[j] -= point[j];
+        }
+        else {
+          for (dimension_type j = gen.size() - 1; j-- > 1; )
+            sub_mul_assign(gen[j], g_div, point[j]);
+        }
+        gen[0] *= p_div;
+        gen.strong_normalize();
 	gen.set_is_parameter();
-	const Grid_Generator& first = *first_point;
-	for (dimension_type i = gen.size() - 1; i-- > 0; )
-	  gen[i] -= first[i];
+        PPL_ASSERT(gen.OK());
       }
+      // Intentionally fall through.
 
     case Grid_Generator::PARAMETER:
     case Grid_Generator::LINE:
-      Grid_Generator& gen = const_cast<Grid_Generator&>(*g);
-      if (gen.is_line_or_parameter())
-	for (dimension_type i = c.space_dimension(); i-- > 0; ) {
-	  Variable v(i);
-	  if (c.coefficient(v) != 0 && gen.coefficient(v) != 0)
-	    return Poly_Con_Relation::strictly_intersects();
-	}
+      {
+        const int sign = c.is_strict_inequality()
+          ? Scalar_Products::reduced_sign(c, g)
+          : Scalar_Products::sign(c, g);
+        if (sign != 0)
+          return Poly_Con_Relation::strictly_intersects();
+      }
       break;
-    }
+    } // switch
+  }
 
+  // If this program point is reached, then all lines and parameters
+  // saturate the constraint. Hence, the result is determined by
+  // the previosly computed relation with the point.
   if (point_saturates)
-    // Any parameters and lines are also included.
     return Poly_Con_Relation::saturates()
       && Poly_Con_Relation::is_included();
+
   if (point_is_included)
-    // Any parameters and lines are also included.
     return Poly_Con_Relation::is_included();
+
   return Poly_Con_Relation::is_disjoint();
 }
 
@@ -1012,11 +1029,11 @@ PPL::Grid::OK(bool check_not_empty) const {
 
 	// A reduced generator system must be the same as a temporary
 	// reduced copy.
-	Dimension_Kinds dk = dim_kinds;
+	Dimension_Kinds dim_kinds_copy = dim_kinds;
 	// `gs' is minimized and marked_empty returned false, so `gs'
 	// should contain rows.
 	PPL_ASSERT(!gs.has_no_rows());
-	simplify(gs, dk);
+	simplify(gs, dim_kinds_copy);
 	// gs contained rows before being reduced, so it should
 	// contain at least a single point afterward.
 	PPL_ASSERT(!gs.has_no_rows());
@@ -1046,11 +1063,12 @@ PPL::Grid::OK(bool check_not_empty) const {
       goto fail;
 
     Grid tmp_gr = *this;
-    Congruence_System cs_copy = tmp_gr.con_sys;
+    // Make a copy here, before changing tmp_gr, to check later.
+    const Congruence_System cs_copy = tmp_gr.con_sys;
 
     // Clear the generators in tmp_gr.
     Grid_Generator_System gs(space_dim);
-    std::swap(tmp_gr.gen_sys, gs);
+    tmp_gr.gen_sys.m_swap(gs);
     tmp_gr.clear_generators_up_to_date();
 
     if (!tmp_gr.update_generators()) {
@@ -1275,7 +1293,7 @@ PPL::Grid::add_recycled_grid_generators(Grid_Generator_System& gs) {
   // Adjust `gs' to the right dimension.
   gs.insert(parameter(0*Variable(space_dim-1)));
 
-  std::swap(gen_sys, gs);
+  gen_sys.m_swap(gs);
 
   normalize_divisors(gen_sys);
 
@@ -1337,7 +1355,7 @@ PPL::Grid::unconstrain(const Variable var) {
 
 void
 PPL::Grid::unconstrain(const Variables_Set& vars) {
-  // The cylindrification wrt no dimensions is a no-op.
+  // The cylindrification with respect to no dimensions is a no-op.
   // This case also captures the only legal cylindrification
   // of a grid in a 0-dim space.
   if (vars.empty())
@@ -1585,7 +1603,7 @@ PPL::Grid::simplify_using_context_assign(const Grid& y) {
   // If `y' is empty, the biggest enlargement for `x' is the universe.
   if (!y.minimize()) {
     Grid gr(x.space_dim, UNIVERSE);
-    swap(gr);
+    m_swap(gr);
     return false;
   }
 
@@ -1620,7 +1638,7 @@ PPL::Grid::simplify_using_context_assign(const Grid& y) {
         }
       }
     }
-    swap(gr);
+    m_swap(gr);
     PPL_ASSERT(OK());
     return false;
   }
@@ -1630,19 +1648,18 @@ PPL::Grid::simplify_using_context_assign(const Grid& y) {
 
   const Congruence_System& x_cs = x.con_sys;
   const dimension_type x_cs_num_rows = x_cs.num_rows();
-  const Grid_Generator_System& y_gs = y.gen_sys;
 
   // Record into `redundant_by_y' the info about which congruences of
   // `x' are redundant in the context `y'.  Count the number of
   // redundancies found.
   std::vector<bool> redundant_by_y(x_cs_num_rows, false);
   dimension_type num_redundant_by_y = 0;
-  for (dimension_type i = 0; i < x_cs_num_rows; ++i)
-    if (y.relation_with(x_cs[i])
-	.implies(Poly_Con_Relation::is_included())) {
+  for (dimension_type i = 0; i < x_cs_num_rows; ++i) {
+    if (y.relation_with(x_cs[i]).implies(Poly_Con_Relation::is_included())) {
       redundant_by_y[i] = true;
       ++num_redundant_by_y;
     }
+  }
 
   if (num_redundant_by_y < x_cs_num_rows) {
 
@@ -1691,6 +1708,7 @@ PPL::Grid::simplify_using_context_assign(const Grid& y) {
 	const Coefficient& modulus = c.modulus();
 	div = modulus;
 
+        const Grid_Generator_System& y_gs = y.gen_sys;
 	dimension_type num_ruled_out_generators = 0;
 	for (Grid_Generator_System::const_iterator k = y_gs.begin(),
 	       y_gs_end = y_gs.end(); k != y_gs_end; ++k) {
@@ -1726,8 +1744,8 @@ PPL::Grid::simplify_using_context_assign(const Grid& y) {
     // Add the congruences in the "ruled out" order to `w'
     // until the result is the intersection.
     for (std::vector<Ruled_Out_Pair>::const_iterator
-	   j = ruled_out_vec.begin(), rov_end = ruled_out_vec.end();
-	 j != rov_end;
+	   j = ruled_out_vec.begin(), ruled_out_vec_end = ruled_out_vec.end();
+	 j != ruled_out_vec_end;
 	 ++j) {
       const Congruence& c = x_cs[j->congruence_index];
       result_cs.insert(c);
@@ -1736,19 +1754,19 @@ PPL::Grid::simplify_using_context_assign(const Grid& y) {
 	  || (!empty_intersection && w.is_included_in(z))) {
 	Grid result_gr(x.space_dim, UNIVERSE);
 	result_gr.add_congruences(result_cs);
-	x.swap(result_gr);
+	x.m_swap(result_gr);
 	PPL_ASSERT(x.OK());
 	return !empty_intersection;
       }
     }
-      // Cannot exit from here.
-    PPL_ASSERT(false);
+    // Cannot exit from here.
+    PPL_UNREACHABLE;
   }
 
   // All the congruences are redundant so that the simplified grid
   // is the universe.
   Grid result_gr(x.space_dim, UNIVERSE);
-  x.swap(result_gr);
+  x.m_swap(result_gr);
   PPL_ASSERT(x.OK());
   return true;
 }
@@ -1914,7 +1932,6 @@ generalized_affine_image(const Variable var,
 			 const Linear_Expression& expr,
 			 Coefficient_traits::const_reference denominator,
 			 Coefficient_traits::const_reference modulus) {
-
   // The denominator cannot be zero.
   if (denominator == 0)
     throw_invalid_argument("generalized_affine_image(v, r, e, d, m)",
@@ -1932,6 +1949,10 @@ generalized_affine_image(const Variable var,
   if (space_dim < var_space_dim)
     throw_dimension_incompatible("generalized_affine_image(v, r, e, d, m)",
 				 "v", var);
+  // The relation symbol cannot be a disequality.
+  if (relsym == NOT_EQUAL)
+    throw_invalid_argument("generalized_affine_image(v, r, e, d, m)",
+                           "r is the disequality relation symbol");
 
   // Any image of an empty grid is empty.
   if (marked_empty())
@@ -1997,20 +2018,24 @@ generalized_affine_preimage(const Variable var,
 			    Coefficient_traits::const_reference modulus) {
   // The denominator cannot be zero.
   if (denominator == 0)
-    throw_invalid_argument("generalized_affine_preimage(v, e, d, m)",
+    throw_invalid_argument("generalized_affine_preimage(v, r, e, d, m)",
 			   "d == 0");
 
   // The dimension of `expr' should be at most the dimension of
   // `*this'.
   const dimension_type expr_space_dim = expr.space_dimension();
   if (space_dim < expr_space_dim)
-    throw_dimension_incompatible("generalized_affine_preimage(v, e, d, m)",
+    throw_dimension_incompatible("generalized_affine_preimage(v, r, e, d, m)",
 				 "e", expr);
   // `var' should be one of the dimensions of the grid.
   const dimension_type var_space_dim = var.space_dimension();
   if (space_dim < var_space_dim)
-    throw_dimension_incompatible("generalized_affine_preimage(v, e, d, m)",
+    throw_dimension_incompatible("generalized_affine_preimage(v, r, e, d, m)",
 				 "v", var);
+  // The relation symbol cannot be a disequality.
+  if (relsym == NOT_EQUAL)
+    throw_invalid_argument("generalized_affine_preimage(v, r, e, d, m)",
+                           "r is the disequality relation symbol");
 
   // If relsym is not EQUAL, then we return a safe approximation
   // by adding a line in the direction of var.
@@ -2092,14 +2117,18 @@ generalized_affine_image(const Linear_Expression& lhs,
   // `*this'.
   dimension_type lhs_space_dim = lhs.space_dimension();
   if (space_dim < lhs_space_dim)
-    throw_dimension_incompatible("generalized_affine_image(e1, r, e2)",
+    throw_dimension_incompatible("generalized_affine_image(e1, r, e2, m)",
 				 "e1", lhs);
   // The dimension of `rhs' should be at most the dimension of
   // `*this'.
   const dimension_type rhs_space_dim = rhs.space_dimension();
   if (space_dim < rhs_space_dim)
-    throw_dimension_incompatible("generalized_affine_image(e1, r, e2)",
+    throw_dimension_incompatible("generalized_affine_image(e1, r, e2, m)",
 				 "e2", rhs);
+  // The relation symbol cannot be a disequality.
+  if (relsym == NOT_EQUAL)
+    throw_invalid_argument("generalized_affine_image(e1, r, e2, m)",
+                           "r is the disequality relation symbol");
 
   // Any image of an empty grid is empty.
   if (marked_empty())
@@ -2162,7 +2191,7 @@ generalized_affine_image(const Linear_Expression& lhs,
   if (lhs_vars_intersect_rhs_vars) {
     // Some variables in `lhs' also occur in `rhs'.
     // To ease the computation, add an additional dimension.
-    const Variable new_var = Variable(space_dim);
+    const Variable new_var(space_dim);
     add_space_dimensions_and_embed(1);
 
     // Constrain the new dimension to be equal to the right hand side.
@@ -2221,17 +2250,20 @@ generalized_affine_preimage(const Linear_Expression& lhs,
 			    const Relation_Symbol relsym,
 			    const Linear_Expression& rhs,
 			    Coefficient_traits::const_reference modulus) {
-
   // The dimension of `lhs' must be at most the dimension of `*this'.
   dimension_type lhs_space_dim = lhs.space_dimension();
   if (space_dim < lhs_space_dim)
-    throw_dimension_incompatible("generalized_affine_preimage(e1, e2, m)",
+    throw_dimension_incompatible("generalized_affine_preimage(e1, r, e2, m)",
 				 "lhs", lhs);
   // The dimension of `rhs' must be at most the dimension of `*this'.
   const dimension_type rhs_space_dim = rhs.space_dimension();
   if (space_dim < rhs_space_dim)
-    throw_dimension_incompatible("generalized_affine_preimage(e1, e2, m)",
+    throw_dimension_incompatible("generalized_affine_preimage(e1, r, e2, m)",
 				 "e2", rhs);
+  // The relation symbol cannot be a disequality.
+  if (relsym == NOT_EQUAL)
+    throw_invalid_argument("generalized_affine_preimage(e1, r, e2, m)",
+                           "r is the disequality relation symbol");
 
   // Any preimage of an empty grid is empty.
   if (marked_empty())
@@ -2295,7 +2327,7 @@ generalized_affine_preimage(const Linear_Expression& lhs,
   if (lhs_vars_intersect_rhs_vars) {
     // Some variables in `lhs' also occur in `rhs'.
     // To ease the computation, add an additional dimension.
-    const Variable new_var = Variable(space_dim);
+    const Variable new_var(space_dim);
     add_space_dimensions_and_embed(1);
 
     // Constrain the new dimension to be equal to `lhs'
@@ -2367,11 +2399,11 @@ bounded_affine_image(const Variable var,
   // greater than the dimension of `*this'.
   const dimension_type lb_space_dim = lb_expr.space_dimension();
   if (space_dim < lb_space_dim)
-    throw_dimension_incompatible("bounded_affine_image(v, lb, ub)",
+    throw_dimension_incompatible("bounded_affine_image(v, lb, ub, d)",
 				 "lb", lb_expr);
   const dimension_type ub_space_dim = ub_expr.space_dimension();
   if (space_dim < ub_space_dim)
-    throw_dimension_incompatible("bounded_affine_image(v, lb, ub)",
+    throw_dimension_incompatible("bounded_affine_image(v, lb, ub, d)",
 				 "ub", ub_expr);
 
   // Any image of an empty grid is empty.
@@ -2410,11 +2442,11 @@ bounded_affine_preimage(const Variable var,
   // greater than the dimension of `*this'.
   const dimension_type lb_space_dim = lb_expr.space_dimension();
   if (space_dim < lb_space_dim)
-    throw_dimension_incompatible("bounded_affine_preimage(v, lb, ub)",
+    throw_dimension_incompatible("bounded_affine_preimage(v, lb, ub, d)",
 				 "lb", lb_expr);
   const dimension_type ub_space_dim = ub_expr.space_dimension();
   if (space_dim < ub_space_dim)
-    throw_dimension_incompatible("bounded_affine_preimage(v, lb, ub)",
+    throw_dimension_incompatible("bounded_affine_preimage(v, lb, ub, d)",
 				 "ub", ub_expr);
 
   // Any preimage of an empty grid is empty.
@@ -2491,8 +2523,8 @@ PPL::Grid::frequency(const Linear_Expression& expr,
   if (space_dim < expr.space_dimension())
     throw_dimension_incompatible("frequency(e, ...)", "e", expr);
 
-  // Space dimension = 0: if empty, then return false;
-  // otherwise the frequency is 1 and the value is 0
+  // Space dimension is 0: if empty, then return false;
+  // otherwise the frequency is 1 and the value is 0.
   if (space_dim == 0) {
     if (is_empty())
       return false;
@@ -2614,13 +2646,11 @@ PPL::Grid::ascii_load(std::istream& s) {
   if (!(s >> str) || str != "con_sys")
     return false;
 
-  if (s >> str) {
-    if (str == "(up-to-date)")
-      set_congruences_up_to_date();
-    else if (str != "(not_up-to-date)")
-      return false;
-  }
-  else
+  if (!(s >> str))
+    return false;
+  if (str == "(up-to-date)")
+    set_congruences_up_to_date();
+  else if (str != "(not_up-to-date)")
     return false;
 
   if (!con_sys.ascii_load(s))
@@ -2629,13 +2659,11 @@ PPL::Grid::ascii_load(std::istream& s) {
   if (!(s >> str) || str != "gen_sys")
     return false;
 
-  if (s >> str) {
-    if (str == "(up-to-date)")
-      set_generators_up_to_date();
-    else if (str != "(not_up-to-date)")
-      return false;
-  }
-  else
+  if (!(s >> str))
+    return false;
+  if (str == "(up-to-date)")
+    set_generators_up_to_date();
+  else if (str != "(not_up-to-date)")
     return false;
 
   if (!gen_sys.ascii_load(s))
@@ -2678,15 +2706,15 @@ PPL::Grid::wrap_assign(const Variables_Set& vars,
                        Bounded_Integer_Type_Width w,
                        Bounded_Integer_Type_Representation r,
                        Bounded_Integer_Type_Overflow o,
-                       const Constraint_System* pcs,
+                       const Constraint_System* cs_p,
                        unsigned /* complexity_threshold */,
                        bool /* wrap_individually */) {
 
-  // Dimension-compatibility check of `*pcs', if any.
-  if (pcs != 0) {
-   const dimension_type pcs_space_dim  = pcs->space_dimension();
-   if (pcs->space_dimension() > space_dim)
-     throw_dimension_incompatible("wrap_assign(vs, ...)", pcs_space_dim);
+  // Dimension-compatibility check of `*cs_p', if any.
+  if (cs_p != 0) {
+    const dimension_type cs_p_space_dim  = cs_p->space_dimension();
+    if (cs_p->space_dimension() > space_dim)
+      throw_dimension_incompatible("wrap_assign(vs, ...)", cs_p_space_dim);
   }
 
   // Wrapping no variable is a no-op.
@@ -2735,8 +2763,8 @@ PPL::Grid::wrap_assign(const Variables_Set& vars,
     PPL_DIRTY_TEMP_COEFFICIENT(v_n);
     PPL_DIRTY_TEMP_COEFFICIENT(v_d);
     for (Variables_Set::const_iterator i = vars.begin(),
-           vars_end = vars.end(); i != vars.end(); ++i) {
-      const Variable x = Variable(*i);
+           vars_end = vars.end(); i != vars_end; ++i) {
+      const Variable x(*i);
       // Find the frequency and a value for `x' in `gr'.
       if (!gr.frequency_no_check(x, f_n, f_d, v_n, v_d))
         continue;
@@ -2817,8 +2845,8 @@ PPL::Grid::wrap_assign(const Variables_Set& vars,
   max_value *= div;
   min_value *= div;
   for (Variables_Set::const_iterator i = vars.begin(),
-         vars_end = vars.end(); i != vars.end(); ++i) {
-    const Variable x = Variable(*i);
+         vars_end = vars.end(); i != vars_end; ++i) {
+    const Variable x(*i);
     if (!gr.bounds_no_check(x)) {
       // `x' is not a constant in `gr'.
       // We know that `x' is not a constant, so `x' may wrap to any
@@ -2886,7 +2914,7 @@ PPL::Grid::drop_some_non_integer_points(const Variables_Set& vars,
   // in vars. All points in \p *this with non-integral coordinates for
   // the dimensions in vars are removed.
   for (Variables_Set::const_iterator i = vars.begin(),
-         vars_end = vars.end(); i != vars.end(); ++i)
+         vars_end = vars.end(); i != vars_end; ++i)
     add_congruence(Variable(*i) %= 0);
 
   PPL_ASSERT(OK());
