@@ -1,7 +1,7 @@
 /* Grid class implementation
    (non-inline widening-related member functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -20,12 +20,10 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Grid.defs.hh"
-
 #include "assert.hh"
 #include <iostream>
 
@@ -33,7 +31,7 @@ namespace PPL = Parma_Polyhedra_Library;
 
 void
 PPL::Grid::select_wider_congruences(const Grid& y,
-				    Congruence_System& cgs_selected) const {
+				    Congruence_System& selected_cgs) const {
   // Private method: the caller must ensure the following conditions
   // (beside the inclusion `y <= x').
   PPL_ASSERT(space_dim == y.space_dim);
@@ -55,41 +53,33 @@ PPL::Grid::select_wider_congruences(const Grid& y,
 	const Congruence& y_cg = y.con_sys[y_row];
 	if (cg.is_equal_at_dimension(dim, y_cg))
 	  // The leading diagonal entries are equal.
-	  cgs_selected.insert(cg);
+	  selected_cgs.insert(cg);
 	++x_row;
 	++y_row;
       }
       break;
     case EQUALITY:
-      cgs_selected.insert(con_sys[x_row]);
+      selected_cgs.insert(con_sys[x_row]);
       ++x_row;
       ++y_row;
       break;
     case CON_VIRTUAL:
-      y.dim_kinds[dim] == CON_VIRTUAL || ++y_row;
+      if (y.dim_kinds[dim] != CON_VIRTUAL)
+        ++y_row;
       break;
     }
   }
 }
 
 void
-PPL::Grid::congruence_widening_assign(const Grid& const_y, unsigned* tp) {
+PPL::Grid::congruence_widening_assign(const Grid& y, unsigned* tp) {
   Grid& x = *this;
-  Grid& y = const_cast<Grid&>(const_y);
   // Dimension-compatibility check.
   if (x.space_dim != y.space_dim)
     throw_dimension_incompatible("widening_assign(y)", "y", y);
 
-  // Stable behavior is only guaranteed if y is contained in or equal
-  // to x.
-#ifndef NDEBUG
-  {
-    // Assume y is contained in or equal to x.
-    const Grid x_copy = x;
-    const Grid y_copy = y;
-    PPL_ASSERT(x_copy.contains(y_copy));
-  }
-#endif
+  // Assume `y' is contained in or equal to `x'.
+  PPL_EXPECT_HEAVY(copy_contains(x, y));
 
   // Leave `x' the same if `x' or `y' is zero-dimensional or empty.
   if (x.space_dim == 0 || x.marked_empty() || y.marked_empty())
@@ -110,26 +100,27 @@ PPL::Grid::congruence_widening_assign(const Grid& const_y, unsigned* tp) {
     x.update_congruences();
 
   // Ensure that the `y' congruences are in minimal form.
-  if (y.congruences_are_up_to_date()) {
-    if (!y.congruences_are_minimized()) {
-      if (simplify(y.con_sys, y.dim_kinds)) {
+  Grid& yy = const_cast<Grid&>(y);
+  if (yy.congruences_are_up_to_date()) {
+    if (!yy.congruences_are_minimized()) {
+      if (simplify(yy.con_sys, yy.dim_kinds)) {
 	// `y' is empty.
-	y.set_empty();
+	yy.set_empty();
 	return;
       }
-      y.set_congruences_minimized();
+      yy.set_congruences_minimized();
     }
   }
   else
-    y.update_congruences();
+    yy.update_congruences();
 
-  if (con_sys.num_equalities() < y.con_sys.num_equalities())
+  if (con_sys.num_equalities() < yy.con_sys.num_equalities())
     return;
 
   // Copy into `cgs' the congruences of `x' that are common to `y',
   // according to the grid widening.
   Congruence_System cgs;
-  x.select_wider_congruences(y, cgs);
+  x.select_wider_congruences(yy, cgs);
 
   if (cgs.num_rows() == con_sys.num_rows())
     // All congruences were selected, thus the result is `x'.
@@ -142,7 +133,7 @@ PPL::Grid::congruence_widening_assign(const Grid& const_y, unsigned* tp) {
 
   // Check whether we are using the widening-with-tokens technique
   // and there are still tokens available.
-  if (tp && *tp > 0) {
+  if (tp != 0 && *tp > 0) {
     // There are tokens available.  If `result' is not a subset of
     // `x', then it is less precise and we use one of the available
     // tokens.
@@ -151,7 +142,7 @@ PPL::Grid::congruence_widening_assign(const Grid& const_y, unsigned* tp) {
   }
   else
     // No tokens.
-    std::swap(x, result);
+    x.m_swap(result);
 
   PPL_ASSERT(x.OK(true));
 }
@@ -179,14 +170,8 @@ PPL::Grid::limited_congruence_extrapolation_assign(const Grid& y,
     return;
   }
 
-#ifndef NDEBUG
-  {
-    // Assume that y is contained in or equal to x.
-    const Grid x_copy = x;
-    const Grid y_copy = y;
-    PPL_ASSERT(x_copy.contains(y_copy));
-  }
-#endif
+  // Assume `y' is contained in or equal to `x'.
+  PPL_EXPECT_HEAVY(copy_contains(x, y));
 
   if (y.marked_empty())
     return;
@@ -228,7 +213,7 @@ PPL::Grid::limited_congruence_extrapolation_assign(const Grid& y,
 
 void
 PPL::Grid::select_wider_generators(const Grid& y,
-				   Grid_Generator_System& ggs_selected) const {
+				   Grid_Generator_System& widened_ggs) const {
   // Private method: the caller must ensure the following conditions
   // (beside the inclusion `y <= x').
   PPL_ASSERT(space_dim == y.space_dim);
@@ -251,47 +236,40 @@ PPL::Grid::select_wider_generators(const Grid& y,
 	const Grid_Generator& y_gg = y.gen_sys[y_row];
 	if (gg.is_equal_at_dimension(dim, y_gg))
 	  // The leading diagonal entry is equal.
-	  ggs_selected.insert(gg);
+	  widened_ggs.insert(gg);
         else {
           Linear_Expression e;
           for (dimension_type i = gg.space_dimension(); i-- > 0; )
             e += gg.coefficient(Variable(i)) * Variable(i);
-          ggs_selected.insert(grid_line(e));
+          widened_ggs.insert(grid_line(e));
 	}
 	++x_row;
 	++y_row;
       }
       break;
     case LINE:
-      ggs_selected.insert(gen_sys[x_row]);
+      widened_ggs.insert(gen_sys[x_row]);
       ++x_row;
       ++y_row;
       break;
     case GEN_VIRTUAL:
-      y.dim_kinds[dim] == GEN_VIRTUAL || ++y_row;
+      if (y.dim_kinds[dim] != GEN_VIRTUAL)
+        ++y_row;
       break;
     }
   }
 }
 
 void
-PPL::Grid::generator_widening_assign(const Grid& const_y, unsigned* tp) {
+PPL::Grid::generator_widening_assign(const Grid& y, unsigned* tp) {
   Grid& x = *this;
-  Grid& y = const_cast<Grid&>(const_y);
+
   // Dimension-compatibility check.
   if (x.space_dim != y.space_dim)
     throw_dimension_incompatible("generator_widening_assign(y)", "y", y);
 
-  // Stable behavior is only guaranteed if y is contained in or equal
-  // to x.
-#ifndef NDEBUG
-  {
-    // Assume y is contained in or equal to x.
-    const Grid x_copy = x;
-    const Grid y_copy = y;
-    PPL_ASSERT(x_copy.contains(y_copy));
-  }
-#endif
+  // Assume `y' is contained in or equal to `x'.
+  PPL_EXPECT_HEAVY(copy_contains(x, y));
 
   // Leave `x' the same if `x' or `y' is zero-dimensional or empty.
   if (x.space_dim == 0 || x.marked_empty() || y.marked_empty())
@@ -312,26 +290,27 @@ PPL::Grid::generator_widening_assign(const Grid& const_y, unsigned* tp) {
     return;
 
   // Ensure that the `y' generators are in minimal form.
-  if (y.generators_are_up_to_date()) {
-    if (!y.generators_are_minimized()) {
-      simplify(y.gen_sys, y.dim_kinds);
-      PPL_ASSERT(!y.gen_sys.has_no_rows());
-      y.set_generators_minimized();
+  Grid& yy = const_cast<Grid&>(y);
+  if (yy.generators_are_up_to_date()) {
+    if (!yy.generators_are_minimized()) {
+      simplify(yy.gen_sys, yy.dim_kinds);
+      PPL_ASSERT(!yy.gen_sys.has_no_rows());
+      yy.set_generators_minimized();
     }
   }
   else
-    y.update_generators();
+    yy.update_generators();
 
-  if (gen_sys.num_rows() > y.gen_sys.num_rows())
+  if (gen_sys.num_rows() > yy.gen_sys.num_rows())
     return;
 
-  if (gen_sys.num_lines() > y.gen_sys.num_lines())
+  if (gen_sys.num_lines() > yy.gen_sys.num_lines())
     return;
 
   // Copy into `ggs' the generators of `x' that are common to `y',
   // according to the grid widening.
   Grid_Generator_System ggs;
-  x.select_wider_generators(y, ggs);
+  x.select_wider_generators(yy, ggs);
 
   if (ggs.num_parameters() == gen_sys.num_parameters())
     // All parameters are kept as parameters, thus the result is `x'.
@@ -344,7 +323,7 @@ PPL::Grid::generator_widening_assign(const Grid& const_y, unsigned* tp) {
 
   // Check whether we are using the widening-with-tokens technique
   // and there are still tokens available.
-  if (tp && *tp > 0) {
+  if (tp != 0 && *tp > 0) {
     // There are tokens available.  If `result' is not a subset of
     // `x', then it is less precise and we use one of the available
     // tokens.
@@ -353,7 +332,7 @@ PPL::Grid::generator_widening_assign(const Grid& const_y, unsigned* tp) {
   }
   else
     // No tokens.
-    std::swap(x, result);
+    x.m_swap(result);
 
   PPL_ASSERT(x.OK(true));
 }
@@ -381,14 +360,8 @@ PPL::Grid::limited_generator_extrapolation_assign(const Grid& y,
     return;
   }
 
-#ifndef NDEBUG
-  {
-    // Assume that y is contained in or equal to x.
-    const Grid x_copy = x;
-    const Grid y_copy = y;
-    PPL_ASSERT(x_copy.contains(y_copy));
-  }
-#endif
+  // Assume `y' is contained in or equal to `x'.
+  PPL_EXPECT_HEAVY(copy_contains(x, y));
 
   if (y.marked_empty())
     return;
@@ -429,23 +402,15 @@ PPL::Grid::limited_generator_extrapolation_assign(const Grid& y,
 }
 
 void
-PPL::Grid::widening_assign(const Grid& const_y, unsigned* tp) {
+PPL::Grid::widening_assign(const Grid& y, unsigned* tp) {
   Grid& x = *this;
-  Grid& y = const_cast<Grid&>(const_y);
+
   // Dimension-compatibility check.
   if (x.space_dim != y.space_dim)
     throw_dimension_incompatible("widening_assign(y)", "y", y);
 
-  // Stable behavior is only guaranteed if y is contained in or equal
-  // to x.
-#ifndef NDEBUG
-  {
-    // Assume y is contained in or equal to x.
-    const Grid x_copy = x;
-    const Grid y_copy = y;
-    PPL_ASSERT(x_copy.contains(y_copy));
-  }
-#endif
+  // Assume `y' is contained in or equal to `x'.
+  PPL_EXPECT_HEAVY(copy_contains(x, y));
 
   // If the `x' congruences are up to date and `y' congruences are up
   // to date use the congruence widening.
@@ -487,14 +452,8 @@ PPL::Grid::limited_extrapolation_assign(const Grid& y,
     return;
   }
 
-#ifndef NDEBUG
-  {
-    // Assume that y is contained in or equal to x.
-    const Grid x_copy = x;
-    const Grid y_copy = y;
-    PPL_ASSERT(x_copy.contains(y_copy));
-  }
-#endif
+  // Assume `y' is contained in or equal to `x'.
+  PPL_EXPECT_HEAVY(copy_contains(x, y));
 
   if (y.marked_empty())
     return;
