@@ -1,7 +1,7 @@
 /* H79_Certificate class implementation
    (non-inline member functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -20,12 +20,10 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "H79_Certificate.defs.hh"
-
 #include "Polyhedron.defs.hh"
 #include "assert.hh"
 #include <iostream>
@@ -65,9 +63,9 @@ PPL::H79_Certificate::H79_Certificate(const Polyhedron& ph)
 int
 PPL::H79_Certificate::compare(const H79_Certificate& y) const {
   if (affine_dim != y.affine_dim)
-    return affine_dim > y.affine_dim ? 1 : -1;
+    return (affine_dim > y.affine_dim) ? 1 : -1;
   if (num_constraints != y.num_constraints)
-    return num_constraints > y.num_constraints ? 1 : -1;
+    return (num_constraints > y.num_constraints) ? 1 : -1;
   // All components are equal.
   return 0;
 }
@@ -112,7 +110,7 @@ PPL::H79_Certificate::compare(const Polyhedron& ph) const {
   // If the number of constraints of `ph' is decreasing, then the chain
   // is stabilizing. If it is increasing, the chain is not stabilizing.
   if (ph_num_constraints != num_constraints)
-    return ph_num_constraints < num_constraints ? 1 : -1;
+    return (ph_num_constraints < num_constraints) ? 1 : -1;
 
   // All components are equal.
   return 0;
