@@ -1,6 +1,6 @@
 /* Init class implementation (non-inline functions and static variables).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,10 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Init.defs.hh"
 #include "Variable.defs.hh"
 #include "fpu.defs.hh"
@@ -39,6 +38,7 @@ site: http://www.cs.unipr.it/ppl/ . */
 #include "Congruence_System.defs.hh"
 #include "Grid_Generator_System.defs.hh"
 #include "Polyhedron.defs.hh"
+#include "Watchdog.defs.hh"
 #include <stdexcept>
 
 namespace PPL = Parma_Polyhedra_Library;
@@ -140,7 +140,7 @@ PPL::Init::Init() {
     // ... the GMP memory allocation functions are set, ...
     ppl_set_GMP_memory_allocation_functions();
     // ... the default output function for Variable objects is set, ...
-    Variable::set_output_function(Variable::default_output_function);
+    Variable::set_output_function(&Variable::default_output_function);
     // ... the Coefficient constants are initialized, ...
     Coefficient_constants_initialize();
     // ... the Linear_Expression class is initialized, ...
@@ -158,6 +158,11 @@ PPL::Init::Init() {
     Grid_Generator_System::initialize();
     Polyhedron::initialize();
 
+#if PPL_HAVE_DECL_SETITIMER && PPL_HAVE_DECL_SIGACTION
+    // ... the Watchdog subsystem is initialized, ...
+    Watchdog::Watchdog::initialize();
+#endif // PPL_HAVE_DECL_SETITIMER && PPL_HAVE_DECL_SIGACTION
+
 #if PPL_CAN_CONTROL_FPU
 
     // ... and the FPU rounding direction is set.
@@ -174,9 +179,9 @@ PPL::Init::Init() {
 
 #endif // PPL_CAN_CONTROL_FPU
 
-    // The default is choosen to have a precision greater than most
-    // precise IEC559 floating point (112 bits of mantissa).
-    set_irrational_precision(128);
+    // The default is chosen to have a precision greater than most
+    // precise IEC 559 floating point (112 bits of mantissa).
+    set_irrational_precision(DEFAULT_IRRATIONAL_PRECISION);
   }
 }
 
@@ -187,6 +192,12 @@ PPL::Init::~Init() {
     // ... the FPU rounding direction is restored, ...
     fpu_set_rounding_direction(old_rounding_direction);
 #endif
+
+#if PPL_HAVE_DECL_SETITIMER && PPL_HAVE_DECL_SIGACTION
+    // ... the Watchdog subsystem is finalized, ...
+    Watchdog::Watchdog::finalize();
+#endif // PPL_HAVE_DECL_SETITIMER && PPL_HAVE_DECL_SIGACTION
+
     // ... the Polyhedron, Grid_Generator_System, Congruence_System,
     // Generator_System, Constraint_System, Grid_Generator,
     // Congruence, Generator and Constraint classes are finalized
