@@ -1,6 +1,6 @@
 /* Linear_Expression class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,11 +19,10 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 
-#include <ppl-config.h>
-
+#include "ppl-config.h"
 #include "Linear_Expression.defs.hh"
 #include "Constraint.defs.hh"
 #include "Generator.defs.hh"
@@ -80,14 +79,14 @@ PPL::Linear_Expression::Linear_Expression(const Congruence& cg)
 }
 
 PPL::Linear_Expression::Linear_Expression(const Variable v)
-  : Linear_Row(v.space_dimension() <= max_space_dimension()
-	       ? v.space_dimension() + 1
+  : Linear_Row((v.space_dimension() <= max_space_dimension())
+	       ? (v.space_dimension() + 1)
 	       : (throw std::length_error("PPL::Linear_Expression::"
 					  "Linear_Expression(v):\n"
 					  "v exceeds the maximum allowed "
 					  "space dimension."),
-		  v.space_dimension() + 1)
-	       , Linear_Row::Flags()) {
+		  (v.space_dimension() + 1)),
+               Linear_Row::Flags()) {
   ++((*this)[v.space_dimension()]);
 }
 
@@ -101,7 +100,7 @@ PPL::Linear_Expression::Linear_Expression(const Variable v, const Variable w)
                             "Linear_Expression(v, w):\n"
                             "v or w exceed the maximum allowed "
                             "space dimension.");
-  construct(space_dim+1, Linear_Row::Flags());
+  resize(space_dim+1);
   if (v_space_dim != w_space_dim) {
     ++((*this)[v_space_dim]);
     --((*this)[w_space_dim]);
@@ -290,7 +289,7 @@ PPL::operator+=(Linear_Expression& e1, const Linear_Expression& e2) {
     Linear_Expression new_e(e2);
     for (dimension_type i = e1_size; i-- > 0; )
       new_e[i] += e1[i];
-    e1.swap(new_e);
+    e1.m_swap(new_e);
   }
   return e1;
 }
@@ -306,7 +305,7 @@ PPL::operator+=(Linear_Expression& e, const Variable v) {
   const dimension_type e_size = e.size();
   if (e_size <= v_space_dim) {
     Linear_Expression new_e(e, v_space_dim+1);
-    e.swap(new_e);
+    e.m_swap(new_e);
   }
   ++e[v_space_dim];
   return e;
@@ -324,7 +323,7 @@ PPL::operator-=(Linear_Expression& e1, const Linear_Expression& e2) {
     Linear_Expression new_e(e1, e2_size);
     for (dimension_type i = e2_size; i-- > 0; )
       new_e[i] -= e2[i];
-    e1.swap(new_e);
+    e1.m_swap(new_e);
   }
   return e1;
 }
@@ -340,7 +339,7 @@ PPL::operator-=(Linear_Expression& e, const Variable v) {
   const dimension_type e_size = e.size();
   if (e_size <= v_space_dim) {
     Linear_Expression new_e(e, v_space_dim+1);
-    e.swap(new_e);
+    e.m_swap(new_e);
   }
   --e[v_space_dim];
   return e;
@@ -368,7 +367,7 @@ PPL::add_mul_assign(Linear_Expression& e,
   const dimension_type e_size = e.size();
   if (e_size <= v_space_dim) {
     Linear_Expression new_e(e, v_space_dim+1);
-    e.swap(new_e);
+    e.m_swap(new_e);
   }
   e[v_space_dim] += n;
   return e;
@@ -387,7 +386,7 @@ PPL::sub_mul_assign(Linear_Expression& e,
   const dimension_type e_size = e.size();
   if (e_size <= v_space_dim) {
     Linear_Expression new_e(e, v_space_dim+1);
-    e.swap(new_e);
+    e.m_swap(new_e);
   }
   e[v_space_dim] -= n;
   return e;
