@@ -1,6 +1,6 @@
 /* Linear_Row class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,10 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Linear_Row.defs.hh"
 #include "Coefficient.defs.hh"
 #include <algorithm>
@@ -143,25 +142,35 @@ PPL::Linear_Row::all_homogeneous_terms_are_zero() const {
 namespace {
 
 // These are the keywords that indicate the individual assertions.
-const char* rpi_valid = "RPI_V";
-const char* is_rpi = "RPI";
-const char* nnc_valid = "NNC_V";
-const char* is_nnc = "NNC";
-const char* bit_names[] = {rpi_valid, is_rpi, nnc_valid, is_nnc};
+const char* rpi_valid_text = "RPI_V";
+const char* is_rpi_text = "RPI";
+const char* nnc_valid_text = "NNC_V";
+const char* is_nnc_text = "NNC";
+const char* bit_texts[] = {rpi_valid_text, is_rpi_text,
+                           nnc_valid_text, is_nnc_text};
 
 } // namespace
 
 void
 PPL::Linear_Row::Flags::ascii_dump(std::ostream& s) const {
-  s << (test_bits(1 << Flags::rpi_validity_bit) ? '+' : '-')
-    << rpi_valid << ' '
-    << (test_bits(1 << Flags::rpi_bit) ? '+' : '-')
-    << is_rpi << ' '
+  bool is_rpi = test_bits(1U << Flags::rpi_bit);
+  bool is_nnc = test_bits(1U << Flags::nnc_bit);
+  bool rpi_valid;
+  bool nnc_valid;
+#ifdef NDEBUG
+  // Dump unhandled bits always as true so to permit loading from a
+  // debug enabled executable without failing assertions.
+  rpi_valid = true;
+  nnc_valid = true;
+#else
+  rpi_valid = test_bits(1U << Flags::rpi_validity_bit);
+  nnc_valid = test_bits(1U << Flags::nnc_validity_bit);
+#endif
+  s << (rpi_valid ? '+' : '-') << rpi_valid_text << ' '
+    << (is_rpi ? '+' : '-') << is_rpi_text << ' '
     << ' '
-    << (test_bits(1 << Flags::nnc_validity_bit) ? '+' : '-')
-    << nnc_valid << ' '
-    << (test_bits(1 << Flags::nnc_bit) ? '+' : '-')
-    << is_nnc;
+    << (nnc_valid ? '+' : '-') << nnc_valid_text << ' '
+    << (is_nnc ? '+' : '-') << is_nnc_text;
 }
 
 PPL_OUTPUT_DEFINITIONS_ASCII_ONLY(Linear_Row::Flags)
@@ -172,15 +181,23 @@ PPL::Linear_Row::Flags::ascii_load(std::istream& s) {
   // Assume that the bits are used in sequence.
   reset_bits(std::numeric_limits<base_type>::max());
   for (unsigned int bit = 0;
-       bit < (sizeof(bit_names) / sizeof(char*));
+       bit < (sizeof(bit_texts) / sizeof(char*));
        ++bit) {
     if (!(s >> str))
       return false;
-    if (str[0] == '+')
-      set_bits(1 << (Row::Flags::first_free_bit + bit));
+    if (str[0] == '+') {
+      bool load = true;
+#ifdef NDEBUG
+      // Do not load unhandled bits.
+      if (bit == rpi_validity_bit || bit == nnc_validity_bit)
+        load = false;
+#endif
+      if (load)
+        set_bits(1U << (Dense_Row::Flags::first_free_bit + bit));
+    }
     else if (str[0] != '-')
       return false;
-    if (str.compare(1, strlen(bit_names[bit]), bit_names[bit]) != 0)
+    if (str.compare(1, strlen(bit_texts[bit]), bit_texts[bit]) != 0)
       return false;
   }
   return true;
@@ -188,7 +205,7 @@ PPL::Linear_Row::Flags::ascii_load(std::istream& s) {
 
 void
 PPL::Linear_Row::ascii_dump(std::ostream& s) const {
-  const Row& x = *this;
+  const Dense_Row& x = *this;
   const dimension_type x_size = x.size();
   s << "size " << x_size << " ";
   for (dimension_type i = 0; i < x_size; ++i)
@@ -209,13 +226,13 @@ PPL::Linear_Row::ascii_load(std::istream& s) {
   if (!(s >> new_size))
     return false;
 
-  Row& x = *this;
+  Dense_Row& x = *this;
   const dimension_type old_size = x.size();
   if (new_size < old_size)
     x.shrink(new_size);
   else if (new_size > old_size) {
-    Row y(new_size, Row::Flags());
-    x.swap(y);
+    Dense_Row y(new_size, Dense_Row::Flags());
+    x.m_swap(y);
   }
 
   for (dimension_type col = 0; col < new_size; ++col)
@@ -223,16 +240,22 @@ PPL::Linear_Row::ascii_load(std::istream& s) {
       return false;
   if (!(s >> str) || str != "f")
     return false;
-  return flags().ascii_load(s);
+  
+  Flags f;
+  if (!f.ascii_load(s))
+    return false;
+  set_flags(f);
+  
+  return true;
 }
 
 bool
 PPL::Linear_Row::OK() const {
-  return Row::OK();
+  return Dense_Row::OK();
 }
 
 bool
 PPL::Linear_Row::OK(const dimension_type row_size,
 		    const dimension_type row_capacity) const {
-  return Row::OK(row_size, row_capacity);
+  return Dense_Row::OK(row_size, row_capacity);
 }
