@@ -1,6 +1,6 @@
 /* Linear_System class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,22 +19,20 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Linear_System.defs.hh"
 #include "Coefficient.defs.hh"
-#include "Row.defs.hh"
+#include "Dense_Row.defs.hh"
 #include "Bit_Matrix.defs.hh"
 #include "Scalar_Products.defs.hh"
+#include "swapping_sort.templates.hh"
 #include <algorithm>
 #include <iostream>
 #include <string>
 #include <deque>
 
-#include "swapping_sort.icc"
-
 namespace PPL = Parma_Polyhedra_Library;
 
 PPL::dimension_type
@@ -55,10 +53,11 @@ PPL::Linear_System::merge_rows_assign(const Linear_System& y) {
   PPL_ASSERT(check_sorted() && y.check_sorted());
   PPL_ASSERT(num_pending_rows() == 0 && y.num_pending_rows() == 0);
 
+  using std::swap;
   Linear_System& x = *this;
 
   // A temporary vector of rows...
-  std::vector<Row> tmp;
+  std::vector<Dense_Row> tmp;
   // ... with enough capacity not to require any reallocations.
   tmp.reserve(compute_capacity(x.num_rows() + y.num_rows(), max_num_rows()));
 
@@ -71,7 +70,7 @@ PPL::Linear_System::merge_rows_assign(const Linear_System& y) {
     const int comp = compare(x[xi], y[yi]);
     if (comp <= 0) {
       // Elements that can be taken from `x' are actually _stolen_ from `x'
-      std::swap(x[xi++], *tmp.insert(tmp.end(), Linear_Row()));
+      swap(x[xi++], *tmp.insert(tmp.end(), Linear_Row()));
       if (comp == 0)
 	// A duplicate element.
 	++yi;
@@ -79,21 +78,23 @@ PPL::Linear_System::merge_rows_assign(const Linear_System& y) {
     else {
       // (comp > 0)
       Linear_Row copy(y[yi++], row_size, row_capacity);
-      std::swap(copy, *tmp.insert(tmp.end(), Linear_Row()));
+      swap(copy, *tmp.insert(tmp.end(), Linear_Row()));
     }
   }
   // Insert what is left.
-  if (xi < x_num_rows)
+  if (xi < x_num_rows) {
     while (xi < x_num_rows)
-      std::swap(x[xi++], *tmp.insert(tmp.end(), Linear_Row()));
-  else
+      swap(x[xi++], *tmp.insert(tmp.end(), Linear_Row()));
+  }
+  else {
     while (yi < y_num_rows) {
       Linear_Row copy(y[yi++], row_size, row_capacity);
-      std::swap(copy, *tmp.insert(tmp.end(), Linear_Row()));
+      swap(copy, *tmp.insert(tmp.end(), Linear_Row()));
     }
+  }
 
   // We get the result vector and let the old one be destroyed.
-  std::swap(tmp, rows);
+  swap(tmp, rows);
   // There are no pending rows.
   unset_pending_rows();
   PPL_ASSERT(check_sorted());
@@ -188,6 +189,7 @@ PPL::Linear_System::insert(const Linear_Row& r) {
   // This method is only used when the system has no pending rows.
   PPL_ASSERT(num_pending_rows() == 0);
 
+  using std::swap;
   const dimension_type old_num_rows = num_rows();
   const dimension_type old_num_columns = num_columns();
   const dimension_type r_size = r.size();
@@ -206,7 +208,7 @@ PPL::Linear_System::insert(const Linear_Row& r) {
     Linear_Row tmp_row(r, old_num_columns, row_capacity);
     // If needed, move the epsilon coefficient to the last position.
     if (!is_necessarily_closed())
-      std::swap(tmp_row[r_size - 1], tmp_row[old_num_columns - 1]);
+      swap(tmp_row[r_size - 1], tmp_row[old_num_columns - 1]);
     add_row(tmp_row);
   }
   else
@@ -246,8 +248,9 @@ PPL::Linear_System::insert_pending(const Linear_Row& r) {
     else {
       // Create a resized copy of the row (and move the epsilon
       // coefficient to its last position).
+      using std::swap;
       Linear_Row tmp_row(r, old_num_columns, row_capacity);
-      std::swap(tmp_row[r_size - 1], tmp_row[old_num_columns - 1]);
+      swap(tmp_row[r_size - 1], tmp_row[old_num_columns - 1]);
       add_pending_row(tmp_row);
     }
   else
@@ -275,8 +278,9 @@ PPL::Linear_System::add_pending_rows(const Linear_System& y) {
 
   // Copy the rows of `y', forcing size and capacity.
   for (dimension_type i = y_n_rows; i-- > 0; ) {
-    Row copy(y[i], x.row_size, x.row_capacity);
-    std::swap(copy, x[x_n_rows+i]);
+    Dense_Row copy(y[i], x.row_size, x.row_capacity);
+    using std::swap;
+    swap(copy, x[x_n_rows+i]);
   }
   // Do not check for strong normalization,
   // because no modification of rows has occurred.
@@ -330,27 +334,17 @@ PPL::Linear_System::sort_rows(const dimension_type first_row,
 			      const dimension_type last_row) {
   PPL_ASSERT(first_row <= last_row && last_row <= num_rows());
   // We cannot mix pending and non-pending rows.
-  PPL_ASSERT(first_row >= first_pending_row()
-             || last_row <= first_pending_row());
-
-  const dimension_type num_elems = last_row - first_row;
-  if (num_elems < 2)
-    return;
-
-  // Build the function objects implementing indirect sort comparison,
-  // indirect unique comparison and indirect swap operation.
-  typedef std::vector<Row> Cont;
-  Indirect_Sort_Compare<Cont, Row_Less_Than> sort_cmp(rows, first_row);
-  Indirect_Unique_Compare<Cont> unique_cmp(rows, first_row);
-  Indirect_Swapper<Cont> swapper(rows, first_row);
-
-  const dimension_type num_duplicates
-    = indirect_sort_and_unique(num_elems, sort_cmp, unique_cmp, swapper);
-
-  if (num_duplicates > 0)
-    rows.erase(rows.begin() + (last_row - num_duplicates),
-               rows.begin() + last_row);
+  PPL_ASSERT(first_row >= first_pending_row() || last_row <= first_pending_row());
 
+  // First sort without removing duplicates.
+  std::vector<Dense_Row>::iterator first = nth_iter(rows, first_row);
+  std::vector<Dense_Row>::iterator last = nth_iter(rows, last_row);
+  Implementation::swapping_sort(first, last, Row_Less_Than());
+  // Second, move duplicates to the end.
+  std::vector<Dense_Row>::iterator new_last
+    = Implementation::swapping_unique(first, last);
+  // Finally, remove duplicates.
+  rows.erase(new_last, last);
   // NOTE: we cannot check all invariants of the system here,
   // because the caller still has to update `index_first_pending'.
 }
@@ -366,7 +360,7 @@ PPL::Linear_System::add_row(const Linear_Row& r) {
 
   const bool was_sorted = is_sorted();
 
-  Matrix::add_row(r);
+  Dense_Matrix::add_row(r);
 
   //  We update `index_first_pending', because it must be equal to
   // `num_rows()'.
@@ -400,28 +394,30 @@ PPL::Linear_System::add_pending_row(const Linear_Row& r) {
   PPL_ASSERT(r.check_strong_normalized());
   PPL_ASSERT(r.size() == row_size);
 
+  using std::swap;
+
   const dimension_type new_rows_size = rows.size() + 1;
   if (rows.capacity() < new_rows_size) {
     // Reallocation will take place.
-    std::vector<Row> new_rows;
+    std::vector<Dense_Row> new_rows;
     new_rows.reserve(compute_capacity(new_rows_size, max_num_rows()));
-    new_rows.insert(new_rows.end(), new_rows_size, Row());
+    new_rows.insert(new_rows.end(), new_rows_size, Dense_Row());
     // Put the new row in place.
-    Row new_row(r, row_capacity);
+    Dense_Row new_row(r, row_capacity);
     dimension_type i = new_rows_size-1;
-    std::swap(new_rows[i], new_row);
+    swap(new_rows[i], new_row);
     // Steal the old rows.
     while (i-- > 0)
-      new_rows[i].swap(rows[i]);
+      new_rows[i].m_swap(rows[i]);
     // Put the new rows into place.
-    std::swap(rows, new_rows);
+    swap(rows, new_rows);
   }
   else {
     // Reallocation will NOT take place.
     // Inserts a new empty row at the end, then substitutes it with a
     // copy of the given row.
-    Row tmp(r, row_capacity);
-    std::swap(*rows.insert(rows.end(), Row()), tmp);
+    Dense_Row tmp(r, row_capacity);
+    swap(*rows.insert(rows.end(), Dense_Row()), tmp);
   }
 
   // The added row was a pending row.
@@ -433,28 +429,29 @@ PPL::Linear_System::add_pending_row(const Linear_Row& r) {
 
 void
 PPL::Linear_System::add_pending_row(const Linear_Row::Flags flags) {
+  using std::swap;
   const dimension_type new_rows_size = rows.size() + 1;
   if (rows.capacity() < new_rows_size) {
     // Reallocation will take place.
-    std::vector<Row> new_rows;
+    std::vector<Dense_Row> new_rows;
     new_rows.reserve(compute_capacity(new_rows_size, max_num_rows()));
-    new_rows.insert(new_rows.end(), new_rows_size, Row());
+    new_rows.insert(new_rows.end(), new_rows_size, Dense_Row());
     // Put the new row in place.
     Linear_Row new_row(row_size, row_capacity, flags);
     dimension_type i = new_rows_size-1;
-    std::swap(new_rows[i], new_row);
+    swap(new_rows[i], new_row);
     // Steal the old rows.
     while (i-- > 0)
-      new_rows[i].swap(rows[i]);
+      new_rows[i].m_swap(rows[i]);
     // Put the new vector into place.
-    std::swap(rows, new_rows);
+    swap(rows, new_rows);
   }
   else {
     // Reallocation will NOT take place.
     // Insert a new empty row at the end, then construct it assigning
     // it the given type.
-    Row& new_row = *rows.insert(rows.end(), Row());
-    static_cast<Linear_Row&>(new_row).construct(row_size, row_capacity, flags);
+    Dense_Row& new_row = *rows.insert(rows.end(), Dense_Row(flags));
+    static_cast<Linear_Row&>(new_row).resize(row_size, row_capacity);
   }
 
   // The added row was a pending row.
@@ -502,7 +499,7 @@ PPL::operator==(const Linear_System& x, const Linear_System& y) {
     return false;
   if (x.first_pending_row() != y.first_pending_row())
     return false;
-  // Notice that calling operator==(const Matrix&, const Matrix&)
+  // Notice that calling operator==(const Dense_Matrix&, const Dense_Matrix&)
   // would be wrong here, as equality of the type fields would
   // not be checked.
   for (dimension_type i = x_num_rows; i-- > 0; )
@@ -521,31 +518,34 @@ PPL::Linear_System::sort_and_remove_with_sat(Bit_Matrix& sat) {
     return;
   }
 
-  const dimension_type num_elems = sat.num_rows();
-  // Build the function objects implementing indirect sort comparison,
-  // indirect unique comparison and indirect swap operation.
-  typedef std::vector<Row> Cont;
-  Indirect_Sort_Compare<Cont, Row_Less_Than> sort_cmp(rows);
-  Indirect_Unique_Compare<Cont> unique_cmp(rows);
-  Indirect_Swapper2<Cont, Bit_Matrix> swapper(rows, sat);
-
-  const dimension_type num_duplicates
-    = indirect_sort_and_unique(num_elems, sort_cmp, unique_cmp, swapper);
+  // First, sort `sys' (keeping `sat' consistent) without removing duplicates.
+  With_Bit_Matrix_iterator first(sys.rows.begin(), sat.rows.begin());
+  typedef With_Bit_Matrix_iterator::difference_type diff_type;
+  With_Bit_Matrix_iterator last
+    = first + static_cast<diff_type>(sat.num_rows());
+  Implementation::swapping_sort(first, last, Row_Less_Than());
+  // Second, move duplicates in `sys' to the end (keeping `sat' consistent).
+  With_Bit_Matrix_iterator new_last
+    = Implementation::swapping_unique(first, last);
 
+  const diff_type dist = last - new_last;
+  PPL_ASSERT(dist >= 0);
+  const dimension_type num_duplicates = static_cast<dimension_type>(dist);
   const dimension_type new_first_pending_row
     = sys.first_pending_row() - num_duplicates;
 
   if (sys.num_pending_rows() > 0) {
     // In this case, we must put the duplicates after the pending rows.
+    using std::swap;
     const dimension_type n_rows = sys.num_rows() - 1;
     for (dimension_type i = 0; i < num_duplicates; ++i)
-      std::swap(sys[new_first_pending_row + i], sys[n_rows - i]);
+      swap(sys[new_first_pending_row + i], sys[n_rows - i]);
   }
   // Erasing the duplicated rows...
-  sys.erase_to_end(sys.num_rows() - num_duplicates);
+  sys.remove_trailing_rows(num_duplicates);
   sys.set_index_first_pending_row(new_first_pending_row);
   // ... and the corresponding rows of the saturation matrix.
-  sat.rows_erase_to_end(num_elems - num_duplicates);
+  sat.remove_trailing_rows(num_duplicates);
   PPL_ASSERT(sys.check_sorted());
   // Now the system is sorted.
   sys.set_sorted(true);
@@ -578,7 +578,8 @@ PPL::Linear_System::gauss(const dimension_type n_lines_or_equalities) {
       // Pivot found: if needed, swap rows so that this one becomes
       // the rank-th row in the linear system.
       if (i > rank) {
-	std::swap(x[i], x[rank]);
+        using std::swap;
+	swap(x[i], x[rank]);
 	// After swapping the system is no longer sorted.
 	changed = true;
       }
@@ -710,12 +711,14 @@ PPL::Linear_System::simplify() {
   PPL_ASSERT(x.num_pending_rows() == 0);
 
   // Partially sort the linear system so that all lines/equalities come first.
-  dimension_type nrows = x.num_rows();
+  const dimension_type old_nrows = x.num_rows();
+  dimension_type nrows = old_nrows;
   dimension_type n_lines_or_equalities = 0;
   for (dimension_type i = 0; i < nrows; ++i)
     if (x[i].is_line_or_equality()) {
       if (n_lines_or_equalities < i) {
-	std::swap(x[i], x[n_lines_or_equalities]);
+        using std::swap;
+	swap(x[i], x[n_lines_or_equalities]);
 	// The system was not sorted.
 	PPL_ASSERT(!x.sorted);
       }
@@ -730,9 +733,10 @@ PPL::Linear_System::simplify() {
     const dimension_type
       num_swaps = std::min(n_lines_or_equalities - rank,
 			   n_rays_or_points_or_inequalities);
+    using std::swap;
     for (dimension_type i = num_swaps; i-- > 0; )
-      std::swap(x[--nrows], x[rank + i]);
-    x.erase_to_end(nrows);
+      swap(x[--nrows], x[rank + i]);
+    x.remove_trailing_rows(old_nrows - nrows);
     x.unset_pending_rows();
     if (n_rays_or_points_or_inequalities > num_swaps)
       x.set_sorted(false);
@@ -753,8 +757,9 @@ PPL::Linear_System::add_rows_and_columns(const dimension_type n) {
   add_zero_rows_and_columns(n, n, Linear_Row::Flags(row_topology));
   Linear_System& x = *this;
   // The old system is moved to the bottom.
+  using std::swap;
   for (dimension_type i = old_n_rows; i-- > 0; )
-    std::swap(x[i], x[i + n]);
+    swap(x[i], x[i + n]);
   for (dimension_type i = n, c = old_n_columns; i-- > 0; ) {
     // The top right-hand sub-system (i.e., the system made of new
     // rows and columns) is set to the specular image of the identity
@@ -791,13 +796,15 @@ PPL::Linear_System::sort_pending_and_remove_duplicates() {
   x.sort_rows(first_pending, x.num_rows());
   // Recompute the number of rows, because we may have removed
   // some rows occurring more than once in the pending part.
-  dimension_type num_rows = x.num_rows();
+  const dimension_type old_num_rows = x.num_rows();
+  dimension_type num_rows = old_num_rows;
 
   dimension_type k1 = 0;
   dimension_type k2 = first_pending;
   dimension_type num_duplicates = 0;
   // In order to erase them, put at the end of the system
   // those pending rows that also occur in the non-pending part.
+  using std::swap;
   while (k1 < first_pending && k2 < num_rows) {
     const int cmp = compare(x[k1], x[k2]);
     if (cmp == 0) {
@@ -808,7 +815,7 @@ PPL::Linear_System::sort_pending_and_remove_duplicates() {
       ++k1;
       // Do not increment `k2'; instead, swap there the next pending row.
       if (k2 < num_rows)
-	std::swap(x[k2], x[k2 + num_duplicates]);
+	swap(x[k2], x[k2 + num_duplicates]);
     }
     else if (cmp < 0)
       // By initial sortedness, we can increment `k1'.
@@ -819,7 +826,7 @@ PPL::Linear_System::sort_pending_and_remove_duplicates() {
       // swap the next pending row in position `k2'.
       ++k2;
       if (num_duplicates > 0 && k2 < num_rows)
-	std::swap(x[k2], x[k2 + num_duplicates]);
+        swap(x[k2], x[k2 + num_duplicates]);
     }
   }
   // If needed, swap any duplicates found past the pending rows
@@ -827,8 +834,8 @@ PPL::Linear_System::sort_pending_and_remove_duplicates() {
   if (num_duplicates > 0) {
     if (k2 < num_rows)
       for (++k2; k2 < num_rows; ++k2)
-	std::swap(x[k2], x[k2 + num_duplicates]);
-    x.erase_to_end(num_rows);
+	swap(x[k2], x[k2 + num_duplicates]);
+    x.remove_trailing_rows(old_num_rows - num_rows);
   }
   // Do not check for strong normalization,
   // because no modification of rows has occurred.
@@ -876,7 +883,7 @@ PPL::Linear_System::OK(const bool check_strong_normalized) const {
   // A non-empty system will contain constraints or generators; in
   // both cases it must have at least one column for the inhomogeneous
   // term and, if it is NNC, another one for the epsilon coefficient.
-  const dimension_type min_cols = is_necessarily_closed() ? 1 : 2;
+  const dimension_type min_cols = is_necessarily_closed() ? 1U : 2U;
   if (num_columns() < min_cols) {
 #ifndef NDEBUG
     cerr << "Linear_System has fewer columns than the minimum "
