@@ -1,6 +1,6 @@
 /* PIP_Problem class implementation: non-inline functions.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,9 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
-#include <ppl-config.h>
+#include "ppl-config.h"
 #include "PIP_Problem.defs.hh"
 #include "PIP_Tree.defs.hh"
 
@@ -132,7 +132,7 @@ PPL::PIP_Problem::solve() const {
 
       // Go through all pending constraints.
       for (Constraint_Sequence::const_iterator
-             cs_i = input_cs.begin() + first_pending_constraint,
+             cs_i = nth_iter(input_cs, first_pending_constraint),
              cs_end = input_cs.end(); cs_i != cs_end; ++cs_i) {
         const Constraint& c = *cs_i;
         const dimension_type c_space_dim = c.space_dimension();
@@ -154,33 +154,51 @@ PPL::PIP_Problem::solve() const {
 
         check_feasible_context = true;
 
-        // Translate constraint into context row.
-        Row row(new_num_cols, Row::Flags());
-        row[0] = c.inhomogeneous_term();
+        x.initial_context.add_zero_rows(1, Row_Flags());
+
+        Row& row = x.initial_context[x.initial_context.num_rows()-1];
+
         {
+          Row::iterator itr = row.end();
+
+          if (c.inhomogeneous_term() != 0) {
+            itr = row.insert(0, c.inhomogeneous_term());
+            // Adjust inhomogeneous term if strict.
+            if (c.is_strict_inequality())
+              --(*itr);
+          } else {
+            // Adjust inhomogeneous term if strict.
+            if (c.is_strict_inequality())
+              itr = row.insert(0, -1);
+          }
           dimension_type i = 1;
+
+          // itr may still be end(), but it can still be used as hint.
           for (Variables_Set::const_iterator
-                 pi = param_begin; pi != param_end; ++pi, ++i) {
-            if (*pi < c_space_dim)
-              row[i] = c.coefficient(Variable(*pi));
-            else
+               pi = param_begin; pi != param_end; ++pi, ++i) {
+            if (*pi < c_space_dim) {
+              Coefficient_traits::const_reference coeff_pi
+                = c.coefficient(Variable(*pi));
+              if (coeff_pi != 0)
+                itr = row.insert(itr, i, coeff_pi);
+            } else
               break;
           }
         }
-        // Adjust inhomogenous term if strict.
-        if (c.is_strict_inequality())
-          --row[0];
-
-        // Insert new row into initial context.
-        x.initial_context.add_row(row);
 
         // If it is an equality, also insert its negation.
         if (c.is_equality()) {
-          for (dimension_type i = new_num_cols; i-- > 0; )
-            neg_assign(row[i], row[i]);
+          x.initial_context.add_zero_rows(1, Row_Flags());
 
-          // Insert new row into initial context.
-          x.initial_context.add_row(row);
+          // The reference `row' has been invalidated.
+
+          Row& last_row = x.initial_context[x.initial_context.num_rows()-1];
+
+          last_row = x.initial_context[x.initial_context.num_rows()-2];
+
+          for (Row::iterator
+               i = last_row.begin(), i_end = last_row.end(); i != i_end; ++i)
+            neg_assign(*i);
         }
       }
 
@@ -214,10 +232,10 @@ PPL::PIP_Problem::solve() const {
                                                      external_space_dim,
                                                      /*indent_level=*/ 0);
       // Update problem status.
-      x.status = (x.current_solution) ? OPTIMIZED : UNSATISFIABLE;
+      x.status = (x.current_solution != 0) ? OPTIMIZED : UNSATISFIABLE;
 
       PPL_ASSERT(OK());
-      return (x.current_solution)
+      return (x.current_solution != 0)
         ? OPTIMIZED_PIP_PROBLEM
         : UNFEASIBLE_PIP_PROBLEM;
     } // End of handler for PARTIALLY_SATISFIABLE case.
@@ -225,7 +243,8 @@ PPL::PIP_Problem::solve() const {
   } // End of switch.
 
   // We should not be here!
-  throw std::runtime_error("PPL internal error");
+  PPL_UNREACHABLE;
+  return UNFEASIBLE_PIP_PROBLEM;
 }
 
 PPL::PIP_Tree
@@ -316,7 +335,7 @@ PPL::PIP_Problem::OK() const {
   if (!initial_context.OK())
     return false;
 
-  if (current_solution) {
+  if (current_solution != 0) {
     // Check well formedness of the solution tree.
     if (!current_solution->OK()) {
 #ifndef NDEBUG
@@ -579,9 +598,9 @@ PPL::PIP_Problem
   }
   if (should_throw)
     throw std::length_error("PPL::PIP_Problem::"
-			    "add_space_dimensions_and_embed(m_v, m_p):\n"
-			    "adding m_v+m_p new space dimensions exceeds "
-			    "the maximum allowed space dimension.");
+                            "add_space_dimensions_and_embed(m_v, m_p):\n"
+                            "adding m_v+m_p new space dimensions exceeds "
+                            "the maximum allowed space dimension.");
   // First add PIP variables ...
   external_space_dim += m_vars;
   // ... then add PIP parameters.
@@ -600,9 +619,9 @@ PPL::PIP_Problem
 ::add_to_parameter_space_dimensions(const Variables_Set& p_vars) {
   if (p_vars.space_dimension() > external_space_dim)
     throw std::invalid_argument("PPL::PIP_Problem::"
-				"add_to_parameter_space_dimension(p_vars):\n"
-				"*this and p_vars are dimension "
-				"incompatible.");
+                                "add_to_parameter_space_dimension(p_vars):\n"
+                                "*this and p_vars are dimension "
+                                "incompatible.");
   const dimension_type original_size = parameters.size();
   parameters.insert(p_vars.begin(), p_vars.end());
   // Do not allow to turn variables into parameters.
@@ -610,8 +629,8 @@ PPL::PIP_Problem
          end = p_vars.end(); p != end; ++p) {
     if (*p < internal_space_dim) {
       throw std::invalid_argument("PPL::PIP_Problem::"
-				  "add_to_parameter_space_dimension(p_vars):"
-				  "p_vars contain variable indices.");
+                                  "add_to_parameter_space_dimension(p_vars):"
+                                  "p_vars contain variable indices.");
     }
   }
 
@@ -689,12 +708,12 @@ PPL::memory_size_type
 PPL::PIP_Problem::external_memory_in_bytes() const {
   memory_size_type n = initial_context.external_memory_in_bytes();
   // Adding the external memory for `current_solution'.
-  if (current_solution)
+  if (current_solution != 0)
     n += current_solution->total_memory_in_bytes();
   // Adding the external memory for `input_cs'.
   n += input_cs.capacity() * sizeof(Constraint);
   for (const_iterator i = input_cs.begin(),
-	 i_end = input_cs.end(); i != i_end; ++i)
+       i_end = input_cs.end(); i != i_end; ++i)
     n += (i->external_memory_in_bytes());
   // FIXME: Adding the external memory for `parameters'.
   n += parameters.size() * sizeof(dimension_type);
@@ -708,7 +727,7 @@ PPL::PIP_Problem::total_memory_in_bytes() const {
 }
 
 void
-PPL::PIP_Problem::print_solution(std::ostream& s, unsigned indent) const {
+PPL::PIP_Problem::print_solution(std::ostream& s, int indent) const {
   switch (status) {
 
   case UNSATISFIABLE:
