@@ -1,6 +1,6 @@
 /* Pointset_Powerset class implementation: non-inline functions.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,9 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
-#include <ppl-config.h>
+#include "ppl-config.h"
 #include "Pointset_Powerset.defs.hh"
 #include "Grid.defs.hh"
 #include <utility>
@@ -33,24 +33,25 @@ void
 PPL::Pointset_Powerset<PPL::NNC_Polyhedron>
 ::difference_assign(const Pointset_Powerset& y) {
   Pointset_Powerset& x = *this;
+  using std::swap;
   // Ensure omega-reduction.
   x.omega_reduce();
   y.omega_reduce();
   Sequence new_sequence = x.sequence;
   for (const_iterator yi = y.begin(), y_end = y.end(); yi != y_end; ++yi) {
-    const NNC_Polyhedron& py = yi->pointset();
+    const NNC_Polyhedron& ph_yi = yi->pointset();
     Sequence tmp_sequence;
-    for (Sequence_const_iterator nsi = new_sequence.begin(),
-	   ns_end = new_sequence.end(); nsi != ns_end; ++nsi) {
+    for (Sequence_const_iterator itr = new_sequence.begin(),
+	   ns_end = new_sequence.end(); itr != ns_end; ++itr) {
       std::pair<NNC_Polyhedron, Pointset_Powerset<NNC_Polyhedron> > partition
-	= linear_partition(py, nsi->pointset());
+	= linear_partition(ph_yi, itr->pointset());
       const Pointset_Powerset<NNC_Polyhedron>& residues = partition.second;
       // Append the contents of `residues' to `tmp_sequence'.
       std::copy(residues.begin(), residues.end(), back_inserter(tmp_sequence));
     }
-    std::swap(tmp_sequence, new_sequence);
+    swap(tmp_sequence, new_sequence);
   }
-  std::swap(x.sequence, new_sequence);
+  swap(x.sequence, new_sequence);
   x.reduced = false;
   PPL_ASSERT_HEAVY(x.OK());
 }
@@ -112,49 +113,49 @@ PPL::check_containment(const NNC_Polyhedron& ph,
 namespace {
 
 #ifdef PPL_DOXYGEN_INCLUDE_IMPLEMENTATION_DETAILS
-//! Uses the congruence \p c to approximately partition the grid \p qq.
+//! Uses the congruence \p c to approximately partition the grid \p gr.
 /*! \relates Parma_Polyhedra_Library::Pointset_Powerset
-  On exit, the intersection of \p qq and congruence \p c is stored
-  in \p qq, whereas a finite set of grids whose set-theoretic union
-  contains the intersection of \p qq with the negation of \p c
+  On exit, the intersection of \p gr and congruence \p c is stored
+  in \p gr, whereas a finite set of grids whose set-theoretic union
+  contains the intersection of \p gr with the negation of \p c
   is added, as a set of new disjuncts, to the powerset \p r.
 */
 #endif // defined(PPL_DOXYGEN_INCLUDE_IMPLEMENTATION_DETAILS)
 bool
 approximate_partition_aux(const PPL::Congruence& c,
-			  PPL::Grid& qq,
+			  PPL::Grid& gr,
 			  PPL::Pointset_Powerset<PPL::Grid>& r) {
   using namespace PPL;
   const Coefficient& c_modulus = c.modulus();
-  Grid qq_copy(qq);
-  qq.add_congruence(c);
-  if (qq.is_empty()) {
-    r.add_disjunct(qq_copy);
+  Grid gr_copy(gr);
+  gr.add_congruence(c);
+  if (gr.is_empty()) {
+    r.add_disjunct(gr_copy);
     return true;
   }
 
-  Congruence_System cgs = qq.congruences();
-  Congruence_System cgs_copy = qq_copy.congruences();
-  // When c is an equality, not satisfied by Grid qq
-  // then add qq to the set r. There is no finite
+  Congruence_System cgs = gr.congruences();
+  Congruence_System cgs_copy = gr_copy.congruences();
+  // When c is an equality, not satisfied by Grid gr
+  // then add gr to the set r. There is no finite
   // partition in this case.
   if (c_modulus == 0) {
     if (cgs.num_equalities() != cgs_copy.num_equalities()) {
-      r.add_disjunct(qq_copy);
+      r.add_disjunct(gr_copy);
       return false;
     }
     return true;
   }
 
-  // When c is a proper congruence but, in qq, this direction has
-  // no congruence, then add qq to the set r. There is no finite
+  // When c is a proper congruence but, in gr, this direction has
+  // no congruence, then add gr to the set r. There is no finite
   // partition in this case.
   if (cgs.num_proper_congruences() != cgs_copy.num_proper_congruences()) {
-    r.add_disjunct(qq_copy);
+    r.add_disjunct(gr_copy);
     return false;
   }
 
-  // When  c is a proper congruence and qq also is discrete
+  // When  c is a proper congruence and gr also is discrete
   // in this direction, then there is a finite partition and that
   // is added to r.
   const Coefficient& c_inhomogeneous_term = c.inhomogeneous_term();
@@ -167,10 +168,10 @@ approximate_partition_aux(const PPL::Congruence& c,
   PPL_DIRTY_TEMP_COEFFICIENT(i);
   for (i = c_modulus; i-- > 0; )
     if (i != n) {
-      Grid qqq(qq_copy);
-      qqq.add_congruence((le+i %= 0) / c_modulus);
-      if (!qqq.is_empty())
-	r.add_disjunct(qqq);
+      Grid gr_tmp(gr_copy);
+      gr_tmp.add_congruence((le+i %= 0) / c_modulus);
+      if (!gr_tmp.is_empty())
+	r.add_disjunct(gr_tmp);
     }
   return true;
 }
@@ -187,16 +188,16 @@ PPL::approximate_partition(const Grid& p, const Grid& q,
   // Ensure that the congruence system of q is minimized
   // before copying and calling approximate_partition_aux().
   (void) q.minimized_congruences();
-  Grid qq = q;
-  const Congruence_System& pcs = p.congruences();
-  for (Congruence_System::const_iterator i = pcs.begin(),
-	 pcs_end = pcs.end(); i != pcs_end; ++i)
-    if (!approximate_partition_aux(*i, qq, r)) {
+  Grid gr = q;
+  const Congruence_System& p_congruences = p.congruences();
+  for (Congruence_System::const_iterator i = p_congruences.begin(),
+	 p_congruences_end = p_congruences.end(); i != p_congruences_end; ++i)
+    if (!approximate_partition_aux(*i, gr, r)) {
       finite_partition = false;
       Pointset_Powerset<Grid> s(q);
-      return std::make_pair(qq, s);
+      return std::make_pair(gr, s);
     }
-  return std::make_pair(qq, r);
+  return std::make_pair(gr, r);
 }
 
 /*! \relates Parma_Polyhedra_Library::Pointset_Powerset */
@@ -239,7 +240,7 @@ PPL::check_containment(const Grid& ph,
           // specification of approximate_partition(), we can
           // ignore checking the remaining temporary disjuncts as they
           // will all have the same lines and equalities and therefore
-          // also not have a finite partition wrt pi.
+          // also not have a finite partition with respect to pi.
           if (!finite_partition)
             break;
 	  new_disjuncts.upper_bound_assign(partition.second);
@@ -257,25 +258,26 @@ void
 PPL::Pointset_Powerset<PPL::Grid>
 ::difference_assign(const Pointset_Powerset& y) {
   Pointset_Powerset& x = *this;
+  using std::swap;
   // Ensure omega-reduction.
   x.omega_reduce();
   y.omega_reduce();
   Sequence new_sequence = x.sequence;
   for (const_iterator yi = y.begin(), y_end = y.end(); yi != y_end; ++yi) {
-    const Grid& py = yi->pointset();
+    const Grid& gr_yi = yi->pointset();
     Sequence tmp_sequence;
-    for (Sequence_const_iterator nsi = new_sequence.begin(),
-	   ns_end = new_sequence.end(); nsi != ns_end; ++nsi) {
+    for (Sequence_const_iterator itr = new_sequence.begin(),
+	   ns_end = new_sequence.end(); itr != ns_end; ++itr) {
       bool finite_partition;
       std::pair<Grid, Pointset_Powerset<Grid> > partition
-	= approximate_partition(py, nsi->pointset(), finite_partition);
+	= approximate_partition(gr_yi, itr->pointset(), finite_partition);
       const Pointset_Powerset<Grid>& residues = partition.second;
       // Append the contents of `residues' to `tmp_sequence'.
       std::copy(residues.begin(), residues.end(), back_inserter(tmp_sequence));
     }
-    std::swap(tmp_sequence, new_sequence);
+    swap(tmp_sequence, new_sequence);
   }
-  std::swap(x.sequence, new_sequence);
+  swap(x.sequence, new_sequence);
   x.reduced = false;
   PPL_ASSERT_HEAVY(x.OK());
 }
