@@ -1,6 +1,6 @@
 /* Poly_Gen_Relation class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,15 +19,13 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Poly_Gen_Relation.defs.hh"
-
+#include "assert.hh"
 #include <iostream>
 #include <string>
-#include "assert.hh"
 
 namespace PPL = Parma_Polyhedra_Library;
 
