@@ -1,7 +1,7 @@
 /* Polyhedron class implementation
    (non-inline operators that may change the dimension of the vector space).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -20,10 +20,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Polyhedron.defs.hh"
 #include "Variables_Set.defs.hh"
 #include "assert.hh"
@@ -41,6 +40,7 @@ PPL::Polyhedron::add_space_dimensions(Linear_System& sys1,
   PPL_ASSERT(sys1.topology() == sys2.topology());
   PPL_ASSERT(sys1.num_columns() == sys2.num_columns());
   PPL_ASSERT(add_dim != 0);
+  using std::swap;
 
   sys1.add_zero_columns(add_dim);
   dimension_type old_index = sys2.first_pending_row();
@@ -57,7 +57,7 @@ PPL::Polyhedron::add_space_dimensions(Linear_System& sys1,
   sat1.resize(sat1.num_rows() + add_dim, sat1.num_columns());
   // The old matrix is moved to the end of the new matrix.
   for (dimension_type i = sat1.num_rows() - add_dim; i-- > 0; )
-    std::swap(sat1[i], sat1[i+add_dim]);
+    swap(sat1[i], sat1[i+add_dim]);
   // Computes the "sat_c", too.
   sat2.transpose_assign(sat1);
 
@@ -74,13 +74,13 @@ PPL::Polyhedron::add_space_dimensions(Linear_System& sys1,
     else {
       for (dimension_type i = sys2.num_rows(); i-- > add_dim; ) {
 	Linear_Row& r = sys2[i];
-	std::swap(r[old_eps_index], r[new_eps_index]);
+	swap(r[old_eps_index], r[new_eps_index]);
       }
       // The upper-right corner of `sys2' contains the J matrix:
       // swap coefficients to preserve sortedness.
       for (dimension_type i = add_dim; i-- > 0; ++old_eps_index) {
 	Linear_Row& r = sys2[i];
-	std::swap(r[old_eps_index], r[old_eps_index + 1]);
+	swap(r[old_eps_index], r[old_eps_index + 1]);
       }
     }
     // NOTE: since we swapped columns in both `sys1' and `sys2',
@@ -92,11 +92,11 @@ void
 PPL::Polyhedron::add_space_dimensions_and_embed(dimension_type m) {
   // The space dimension of the resulting polyhedron should not
   // overflow the maximum allowed space dimension.
-  if (m > max_space_dimension() - space_dimension())
-    throw_space_dimension_overflow(topology(),
-				   "add_space_dimensions_and_embed(m)",
-				   "adding m new space dimensions exceeds "
-				   "the maximum allowed space dimension");
+  check_space_dimension_overflow(m, max_space_dimension() - space_dimension(),
+                                 topology(),
+                                 "add_space_dimensions_and_embed(m)",
+                                 "adding m new space dimensions exceeds "
+                                 "the maximum allowed space dimension");
 
   // Adding no dimensions to any polyhedron is a no-op.
   if (m == 0)
@@ -118,7 +118,7 @@ PPL::Polyhedron::add_space_dimensions_and_embed(dimension_type m) {
     // We swap `*this' with a newly created
     // universe polyhedron of dimension `m'.
     Polyhedron ph(topology(), m, UNIVERSE);
-    swap(ph);
+    m_swap(ph);
     return;
   }
 
@@ -161,17 +161,18 @@ PPL::Polyhedron::add_space_dimensions_and_embed(dimension_type m) {
       if (!gen_sys.is_sorted())
 	gen_sys.swap_columns(space_dim + 1, space_dim + 1 + m);
       else {
+        using std::swap;
 	dimension_type old_eps_index = space_dim + 1;
 	dimension_type new_eps_index = old_eps_index + m;
 	for (dimension_type i = gen_sys.num_rows(); i-- > m; ) {
 	  Generator& r = gen_sys[i];
-	  std::swap(r[old_eps_index], r[new_eps_index]);
+	  swap(r[old_eps_index], r[new_eps_index]);
 	}
 	// The upper-right corner of `gen_sys' contains the J matrix:
 	// swap coefficients to preserve sortedness.
 	for (dimension_type i = m; i-- > 0; ++old_eps_index) {
 	  Generator& r = gen_sys[i];
-	  std::swap(r[old_eps_index], r[old_eps_index + 1]);
+	  swap(r[old_eps_index], r[old_eps_index + 1]);
 	}
       }
     }
@@ -188,11 +189,11 @@ void
 PPL::Polyhedron::add_space_dimensions_and_project(dimension_type m) {
   // The space dimension of the resulting polyhedron should not
   // overflow the maximum allowed space dimension.
-  if (m > max_space_dimension() - space_dimension())
-    throw_space_dimension_overflow(topology(),
-				   "add_space_dimensions_and_project(m)",
-				   "adding m new space dimensions exceeds "
-				   "the maximum allowed space dimension");
+  check_space_dimension_overflow(m, max_space_dimension() - space_dimension(),
+                                 topology(),
+                                 "add_space_dimensions_and_project(m)",
+                                 "adding m new space dimensions exceeds "
+                                 "the maximum allowed space dimension");
 
   // Adding no dimensions to any polyhedron is a no-op.
   if (m == 0)
@@ -228,7 +229,7 @@ PPL::Polyhedron::add_space_dimensions_and_project(dimension_type m) {
   // In contrast, in the system of constraints, new rows are needed
   // in order to avoid embedding the old polyhedron in the new space.
   // Thus, for each new dimensions `x[k]', we add the constraint
-  // x[k] = 0; this is done by invoking the function add_space_dimensions()
+  // x[k] = 0: this is done by invoking the function add_space_dimensions()
   // giving the system of constraints as the second argument.
   if (constraints_are_up_to_date())
     if (generators_are_up_to_date()) {
@@ -236,7 +237,7 @@ PPL::Polyhedron::add_space_dimensions_and_project(dimension_type m) {
       if (!sat_g_is_up_to_date())
 	update_sat_g();
       // Adds rows and/or columns to both matrices.
-      // `add_space_dimensions' correctly handles pending constraints
+      // `add_space_dimensions()' correctly handles pending constraints
       // or generators.
       add_space_dimensions(gen_sys, con_sys, sat_g, sat_c, m);
     }
@@ -252,17 +253,18 @@ PPL::Polyhedron::add_space_dimensions_and_project(dimension_type m) {
 	if (!con_sys.is_sorted())
 	  con_sys.swap_columns(space_dim + 1, space_dim + 1 + m);
 	else {
+          using std::swap;
 	  dimension_type old_eps_index = space_dim + 1;
 	  dimension_type new_eps_index = old_eps_index + m;
 	  for (dimension_type i = con_sys.num_rows(); i-- > m; ) {
 	    Constraint& r = con_sys[i];
-	    std::swap(r[old_eps_index], r[new_eps_index]);
+	    swap(r[old_eps_index], r[new_eps_index]);
 	  }
 	  // The upper-right corner of `con_sys' contains the J matrix:
 	  // swap coefficients to preserve sortedness.
 	  for (dimension_type i = m; i-- > 0; ++old_eps_index) {
 	    Constraint& r = con_sys[i];
-	    std::swap(r[old_eps_index], r[old_eps_index + 1]);
+	    swap(r[old_eps_index], r[old_eps_index + 1]);
 	  }
 	}
       }
@@ -292,11 +294,12 @@ PPL::Polyhedron::concatenate_assign(const Polyhedron& y) {
   // The space dimension of the resulting polyhedron should not
   // overflow the maximum allowed space dimension.
   const dimension_type added_columns = y.space_dim;
-  if (added_columns > max_space_dimension() - space_dim)
-    throw_space_dimension_overflow(topology(),
-				   "concatenate_assign(y)",
-				   "concatenation exceeds the maximum "
-				   "allowed space dimension");
+  check_space_dimension_overflow(added_columns,
+                                 max_space_dimension() - space_dimension(),
+                                 topology(),
+                                 "concatenate_assign(y)",
+                                 "concatenation exceeds the maximum "
+                                 "allowed space dimension");
 
   // If `*this' or `y' are empty polyhedra, it is sufficient to adjust
   // the dimension of the space.
@@ -354,11 +357,12 @@ PPL::Polyhedron::concatenate_assign(const Polyhedron& y) {
     if (c_old.is_equality())
       c_new.set_is_equality();
     // The inhomogeneous term is not displaced.
-    std::swap(c_new[0], c_old[0]);
+    using std::swap;
+    swap(c_new[0], c_old[0]);
     // All homogeneous terms (included the epsilon coefficient,
     // if present) are displaced by `space_dim' columns.
     for (dimension_type j = 1; j < cs_num_columns; ++j)
-      std::swap(c_old[j], c_new[space_dim + j]);
+      swap(c_old[j], c_new[space_dim + j]);
   }
 
   if (can_have_something_pending()) {
@@ -376,7 +380,7 @@ PPL::Polyhedron::concatenate_assign(const Polyhedron& y) {
     gen_sys.unset_pending_rows();
     // Since we added new lines at the beginning of `x.gen_sys',
     // we also have to adjust the saturation matrix `sat_c'.
-    // FIXME: if `sat_c' is not up-to-date, couldn't we directly update
+    // FIXME: if `sat_c' is not up-to-date, could not we directly update
     // `sat_g' by resizing it and shifting its columns?
     if (!sat_c_is_up_to_date()) {
       sat_c.transpose_assign(sat_g);
@@ -387,8 +391,9 @@ PPL::Polyhedron::concatenate_assign(const Polyhedron& y) {
     // The old saturation rows are copied at the end of the matrix.
     // The newly introduced lines saturate all the non-pending constraints,
     // thus their saturation rows are made of zeroes.
+    using std::swap;
     for (dimension_type i = sat_c.num_rows() - added_columns; i-- > 0; )
-      std::swap(sat_c[i], sat_c[i+added_columns]);
+      swap(sat_c[i], sat_c[i+added_columns]);
     // Since `added_rows > 0', we now have pending constraints.
     set_constraints_pending();
   }
@@ -462,13 +467,13 @@ PPL::Polyhedron::remove_space_dimensions(const Variables_Set& vars) {
     const dimension_type vsi_col = *vsi + 1;
     // All columns in between are moved to the left.
     while (src_col < vsi_col)
-      gen_sys.Matrix::swap_columns(dst_col++, src_col++);
+      gen_sys.Dense_Matrix::swap_columns(dst_col++, src_col++);
     ++src_col;
   }
   // Moving the remaining columns.
   const dimension_type gen_sys_num_columns = gen_sys.num_columns();
   while (src_col < gen_sys_num_columns)
-    gen_sys.Matrix::swap_columns(dst_col++, src_col++);
+    gen_sys.Dense_Matrix::swap_columns(dst_col++, src_col++);
 
   // The number of remaining columns is `dst_col'.
   // Note that resizing also calls `set_sorted(false)'.
@@ -554,11 +559,11 @@ PPL::Polyhedron::expand_space_dimension(Variable var, dimension_type m) {
 
   // The space dimension of the resulting polyhedron should not
   // overflow the maximum allowed space dimension.
-  if (m > max_space_dimension() - space_dimension())
-    throw_space_dimension_overflow(topology(),
-				   "expand_dimension(v, m)",
-				   "adding m new space dimensions exceeds "
-				   "the maximum allowed space dimension");
+  check_space_dimension_overflow(m, max_space_dimension() - space_dimension(),
+                                 topology(),
+                                 "expand_dimension(v, m)",
+                                 "adding m new space dimensions exceeds "
+                                 "the maximum allowed space dimension");
 
   // Nothing to do, if no dimensions must be added.
   if (m == 0)
@@ -587,7 +592,7 @@ PPL::Polyhedron::expand_space_dimension(Variable var, dimension_type m) {
       for (dimension_type j = old_dim; j-- > 0; )
 	e +=
 	  c.coefficient(Variable(j))
-	  * (j == src_d ? Variable(dst_d) : Variable(j));
+	  * ((j == src_d) ? Variable(dst_d) : Variable(j));
       e += c.inhomogeneous_term();
       new_constraints.insert(c.is_equality()
 			     ? (e == 0)
@@ -625,7 +630,7 @@ PPL::Polyhedron::fold_space_dimensions(const Variables_Set& vars,
 			   "v should not occur in vs");
 
   // All of the affine images we are going to compute are not invertible,
-  // hence we will need to compute the generators of the polyehdron.
+  // hence we will need to compute the generators of the polyhedron.
   // Since we keep taking copies, make sure that a single conversion
   // from constraints to generators is computed.
   (void) generators();
