@@ -1,6 +1,6 @@
 /* Variable class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,9 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
-#include <ppl-config.h>
+#include "ppl-config.h"
 #include "Variable.defs.hh"
 #include <iostream>
 
@@ -36,16 +36,18 @@ PPL::Variable::OK() const {
 }
 
 void
-PPL::Variable::default_output_function(std::ostream& s, const Variable& v) {
+PPL::Variable::default_output_function(std::ostream& s, const Variable v) {
   dimension_type varid = v.id();
-  s << static_cast<char>('A' + varid % 26);
-  if (dimension_type i = varid / 26)
+  static const char var_name_letters[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+  const dimension_type num_letters = sizeof(var_name_letters) - 1;
+  s << var_name_letters[varid % num_letters];
+  if (dimension_type i = varid / num_letters)
     s << i;
 }
 
 /*! \relates Parma_Polyhedra_Library::Variable */
 std::ostream&
-PPL::IO_Operators::operator<<(std::ostream& s, const Variable& v) {
+PPL::IO_Operators::operator<<(std::ostream& s, const Variable v) {
   (*Variable::current_output_function)(s, v);
   return s;
 }
