@@ -37,8 +37,16 @@ void
 PPL::ppl_unreachable_msg(const char* msg,
                          const char* file, unsigned int line,
                          const char* function) {
-  std::cerr << "Aborting PPL computation!\n";
-  std::cerr << file << ":" << line << ": " << function << ": " << msg << "\n";
+  std::cerr << file << ":" << line << ": " << function
+            << ": Latent fault detected: " << msg << ".\n";
   abort();
 }
 
+void
+PPL::ppl_assertion_failed(const char* assertion_text,
+                          const char* file, unsigned int line,
+                          const char* function) {
+  std::cerr << file << ":" << line << ": " << function
+            << ": Assertion `" << assertion_text << "' failed.\n";
+  abort();
+}
