@@ -1,6 +1,6 @@
 /* Polyhedron class implementation: minimize() and add_and_minimize().
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,9 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
-#include <ppl-config.h>
+#include "ppl-config.h"
 #include "Linear_Row.defs.hh"
 #include "Linear_System.defs.hh"
 #include "Bit_Matrix.defs.hh"
@@ -148,7 +148,7 @@ PPL::Polyhedron::minimize(const bool con_to_gen,
   const dimension_type checking_index
     = dest.is_necessarily_closed()
     ? 0
-    : dest.num_columns() - 1;
+    : (dest.num_columns() - 1);
   dimension_type first_point;
   for (first_point = num_lines_or_equalities;
        first_point < dest_num_rows;
@@ -160,7 +160,7 @@ PPL::Polyhedron::minimize(const bool con_to_gen,
     if (con_to_gen)
       // No point has been found: the polyhedron is empty.
       return true;
-    else
+    else {
       // Here `con_to_gen' is false: `dest' is a system of constraints.
       // In this case the condition `first_point == dest_num_rows'
       // actually means that all the constraints in `dest' have their
@@ -169,7 +169,9 @@ PPL::Polyhedron::minimize(const bool con_to_gen,
       // the constraint system `dest' lacks the positivity constraint
       // and no linear combination of the constraints in `dest'
       // can reintroduce the positivity constraint.
-      throw std::runtime_error("PPL internal error");
+      PPL_UNREACHABLE;
+      return false;
+    }
   else {
     // A point has been found: the polyhedron is not empty.
     // Now invoking simplify() to remove all the redundant constraints
@@ -363,19 +365,19 @@ PPL::Polyhedron::add_and_minimize(const bool con_to_gen,
   const dimension_type checking_index
     = dest.is_necessarily_closed()
     ? 0
-    : dest.num_columns() - 1;
+    : (dest.num_columns() - 1);
   dimension_type first_point;
   for (first_point = num_lines_or_equalities;
        first_point < dest_num_rows;
        ++first_point)
-     if (dest[first_point][checking_index] > 0)
+    if (dest[first_point][checking_index] > 0)
       break;
 
   if (first_point == dest_num_rows)
     if (con_to_gen)
       // No point has been found: the polyhedron is empty.
       return true;
-    else
+    else {
       // Here `con_to_gen' is false: `dest' is a system of constraints.
       // In this case the condition `first_point == dest_num_rows'
       // actually means that all the constraints in `dest' have their
@@ -384,7 +386,9 @@ PPL::Polyhedron::add_and_minimize(const bool con_to_gen,
       // the constraint system `dest' lacks the positivity constraint
       // and no linear combination of the constraints in `dest'
       // can reintroduce the positivity constraint.
-      throw std::runtime_error("PPL internal error");
+      PPL_UNREACHABLE;
+      return false;
+    }
   else {
     // A point has been found: the polyhedron is not empty.
     // Now invoking `simplify()' to remove all the redundant constraints
