@@ -1,8 +1,7 @@
 /* Definitions of specializations of std::numeric_limits objects for
-   multi-precision types.  This will become obsolete when GMP and MPFR
-   will provide the specializations by themselves.
+   multi-precision types.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -21,9 +20,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
-#include <ppl-config.h>
+#include "ppl-config.h"
 #include "mp_std_bits.defs.hh"
 
 const bool std::numeric_limits<mpz_class>::is_specialized;
