@@ -1,6 +1,6 @@
 /* Polyhedron class implementation: simplify().
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,10 +19,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "Linear_Row.defs.hh"
 #include "Linear_System.defs.hh"
 #include "Bit_Matrix.defs.hh"
@@ -86,10 +85,13 @@ PPL::Polyhedron::simplify(Linear_System& sys, Bit_Matrix& sat) {
   PPL_ASSERT(sys.OK(true));
   PPL_ASSERT(sys.num_columns() >= 1);
 
-  dimension_type num_rows = sys.num_rows();
+  const dimension_type old_num_rows = sys.num_rows();
+  dimension_type num_rows = old_num_rows;
   const dimension_type num_columns = sys.num_columns();
   const dimension_type num_cols_sat = sat.num_columns();
 
+  using std::swap;
+
   // Looking for the first inequality in `sys'.
   dimension_type num_lines_or_equalities = 0;
   while (num_lines_or_equalities < num_rows
@@ -124,9 +126,9 @@ PPL::Polyhedron::simplify(Linear_System& sys, Bit_Matrix& sat) {
       // We also move it just after all the other equalities,
       // so that system `sys' keeps its partial sortedness.
       if (i != num_lines_or_equalities) {
-	std::swap(sys[i], sys[num_lines_or_equalities]);
-	std::swap(sat[i], sat[num_lines_or_equalities]);
-	std::swap(num_saturators[i], num_saturators[num_lines_or_equalities]);
+	swap(sys[i], sys[num_lines_or_equalities]);
+	swap(sat[i], sat[num_lines_or_equalities]);
+	swap(num_saturators[i], num_saturators[num_lines_or_equalities]);
       }
       ++num_lines_or_equalities;
       // `sys' is no longer sorted.
@@ -168,9 +170,9 @@ PPL::Polyhedron::simplify(Linear_System& sys, Bit_Matrix& sat) {
 	   && erasing > num_lines_or_equalities;
 	 ) {
       --erasing;
-      std::swap(sys[redundant], sys[erasing]);
-      std::swap(sat[redundant], sat[erasing]);
-      std::swap(num_saturators[redundant], num_saturators[erasing]);
+      swap(sys[redundant], sys[erasing]);
+      swap(sat[redundant], sat[erasing]);
+      swap(num_saturators[redundant], num_saturators[erasing]);
       sys.set_sorted(false);
       ++redundant;
     }
@@ -190,11 +192,12 @@ PPL::Polyhedron::simplify(Linear_System& sys, Bit_Matrix& sat) {
   // condition for an inequality to be irredundant (i.e., it provides
   // a sufficient condition for identifying redundant inequalities).
   // Let
-  //   num_saturators[i] = num_sat_lines[i] + num_sat_rays_or_points[i];
-  //   dim_lin_space = num_irred_lines;
+  //
+  //   num_saturators[i] = num_sat_lines[i] + num_sat_rays_or_points[i],
+  //   dim_lin_space = num_irredundant_lines,
   //   dim_ray_space
-  //     = dim_vector_space - num_irred_equalities - dim_lin_space
-  //     = num_columns - 1 - num_lines_or_equalities - dim_lin_space;
+  //     = dim_vector_space - num_irredundant_equalities - dim_lin_space
+  //     = num_columns - 1 - num_lines_or_equalities - dim_lin_space,
   //   min_sat_rays_or_points = dim_ray_space.
   //
   // An inequality saturated by less than `dim_ray_space' _rays/points_
@@ -218,9 +221,9 @@ PPL::Polyhedron::simplify(Linear_System& sys, Bit_Matrix& sat) {
     if (num_saturators[i] < min_saturators) {
       // The inequality `sys[i]' is redundant.
       --num_rows;
-      std::swap(sys[i], sys[num_rows]);
-      std::swap(sat[i], sat[num_rows]);
-      std::swap(num_saturators[i], num_saturators[num_rows]);
+      swap(sys[i], sys[num_rows]);
+      swap(sat[i], sat[num_rows]);
+      swap(num_saturators[i], num_saturators[num_rows]);
       sys.set_sorted(false);
     }
     else
@@ -266,9 +269,9 @@ PPL::Polyhedron::simplify(Linear_System& sys, Bit_Matrix& sat) {
 	    // generators. Then we can remove either one of the two
 	    // inequalities: we remove `sys[j]'.
 	    --num_rows;
-	    std::swap(sys[j], sys[num_rows]);
-	    std::swap(sat[j], sat[num_rows]);
-	    std::swap(num_saturators[j], num_saturators[num_rows]);
+	    swap(sys[j], sys[num_rows]);
+	    swap(sat[j], sat[num_rows]);
+	    swap(num_saturators[j], num_saturators[num_rows]);
 	    sys.set_sorted(false);
 	  }
 	else
@@ -281,9 +284,9 @@ PPL::Polyhedron::simplify(Linear_System& sys, Bit_Matrix& sat) {
     if (redundant) {
       // The inequality `sys[i]' is redundant.
       --num_rows;
-      std::swap(sys[i], sys[num_rows]);
-      std::swap(sat[i], sat[num_rows]);
-      std::swap(num_saturators[i], num_saturators[num_rows]);
+      swap(sys[i], sys[num_rows]);
+      swap(sat[i], sat[num_rows]);
+      swap(num_saturators[i], num_saturators[num_rows]);
       sys.set_sorted(false);
     }
     else
@@ -293,9 +296,9 @@ PPL::Polyhedron::simplify(Linear_System& sys, Bit_Matrix& sat) {
 
   // Here we physically remove the redundant inequalities previously
   // moved to the bottom of `sys' and the corresponding `sat' rows.
-  sys.erase_to_end(num_rows);
+  sys.remove_trailing_rows(old_num_rows - num_rows);
   sys.unset_pending_rows();
-  sat.rows_erase_to_end(num_rows);
+  sat.remove_trailing_rows(old_num_rows - num_rows);
   // At this point the first `num_lines_or_equalities' rows of 'sys'
   // represent the irredundant equalities, while the remaining rows
   // (i.e., those having indexes from `num_lines_or_equalities' to
