@@ -1,6 +1,6 @@
 /* String wrapping helper function.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,11 +19,11 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
-
-#include <ppl-config.h>
+site: http://bugseng.com/products/ppl/ . */
 
+#include "ppl-config.h"
 #include "wrap_string.hh"
+#include "assert.hh"
 #include <cstdlib>
 
 namespace Parma_Polyhedra_Library {
@@ -32,51 +32,53 @@ namespace IO_Operators {
 
 std::string
 wrap_string(const std::string& src_string,
-	    unsigned indent_depth,
-	    unsigned preferred_first_line_length,
-	    unsigned preferred_line_length) {
+	    const unsigned indent_depth,
+	    const unsigned preferred_first_line_length,
+	    const unsigned preferred_line_length) {
+  const unsigned npos = C_Integer<unsigned>::max;
   std::string dst_string;
   const char *src = src_string.c_str();
-  for (int line = 0; ; ++line) {
-    int linelen = (line == 0
-                   ? preferred_first_line_length
-                   : preferred_line_length);
-    int last_comma = -1;
-    int last_space = -1;
-    int split_pos = -1;
-    int i;
-    for (i = 0; i <= linelen; ++i) {
-      if (src[i] == '\0' || src[i] == '\n') {
-	split_pos = i;
+  for (unsigned line = 0; ; ++line) {
+    const unsigned line_length = ((line == 0)
+                                  ? preferred_first_line_length
+                                  : preferred_line_length);
+    unsigned last_comma = npos;
+    unsigned last_space = npos;
+    unsigned split_pos = npos;
+    unsigned idx;
+    for (idx = 0; idx <= line_length; ++idx) {
+      if (src[idx] == '\0' || src[idx] == '\n') {
+	split_pos = idx;
 	break;
       }
-      if (src[i] == ',' && i < linelen)
-	last_comma = i;
-      if (isspace(src[i]) && (i == 0 || !isspace(src[i-1])))
-	last_space = i;
+      if (src[idx] == ',' && idx < line_length)
+	last_comma = idx;
+      if (is_space(src[idx]) && (idx == 0 || !is_space(src[idx-1])))
+	last_space = idx;
     }
-    if (split_pos < 0) {
-      if (last_comma >= 0)
+    if (split_pos == npos) {
+      if (last_comma != npos)
 	split_pos = last_comma + 1;
-      else if (last_space >= 0)
+      else if (last_space != npos)
 	split_pos = last_space;
       else {
-	for ( ; src[i]; ++i) {
-	  if (src[i] == ',') {
-	    ++i;
+	for ( ; src[idx] != '\0'; ++idx) {
+	  if (src[idx] == ',') {
+	    ++idx;
 	    break;
 	  }
-	  if (isspace(src[i]))
+	  if (is_space(src[idx]))
 	    break;
 	}
-	split_pos = i;
+	split_pos = idx;
       }
     }
+    PPL_ASSERT(split_pos != npos);
     if (split_pos > 0 && line > 0 && indent_depth > 0)
-	dst_string.append(indent_depth, ' ');
+      dst_string.append(indent_depth, ' ');
     dst_string.append(src, split_pos);
     src += split_pos;
-    if (isspace(*src))
+    if (is_space(*src))
       ++src;
     while (*src == ' ')
       ++src;
