@@ -1,7 +1,7 @@
 /* Test Box::refine_with_constraints(const Constraint_System&) with
    instances that may require a watchdog timer.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -20,10 +20,9 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl_test.hh"
-#include "pwl.hh"
 #include <sstream>
 
 namespace {
@@ -80,7 +79,7 @@ test01() {
     // refinement instance does not terminate: we use a watchdog timer.
     try {
       // Set a 0.1 seconds timeout.
-      Parma_Watchdog_Library::Watchdog
+      Parma_Polyhedra_Library::Watchdog
         w(10, abandon_expensive_computations, t);
 
       box.refine_with_constraints(cs);
@@ -397,7 +396,7 @@ test02() {
     // very slowly: we use a watchdog timer.
     try {
       // Set a 0.5 seconds timeout.
-      Parma_Watchdog_Library::Watchdog
+      Parma_Polyhedra_Library::Watchdog
         w(50, abandon_expensive_computations, t);
 
       box.refine_with_constraints(cs);
