@@ -1,6 +1,6 @@
 /* Test Box::relation_with().
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,7 +19,7 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl_test.hh"
 
@@ -432,6 +432,7 @@ test19() {
   try {
     // This tests the space dimension exception..
    Poly_Con_Relation rel = box.relation_with((A + B %= 1) / 9);
+   (void) rel;
   }
   catch (std::invalid_argument& e) {
     nout << "std::invalid_argument: " << endl;
