@@ -70,8 +70,8 @@ public:
 };
 
 using namespace Parma_Polyhedra_Library::IO_Operators;
-Concrete_Expression_Type FP_Type =
-  Concrete_Expression_Type::floating_point(ANALYZED_FP_FORMAT);
+Concrete_Expression_Type FP_Type
+= Concrete_Expression_Type::floating_point(ANALYZED_FP_FORMAT);
 
 typedef Integer_Interval Int_Interval;
 
