@@ -1,6 +1,6 @@
 /* Test Pointset_Powerset<PH>::BHZ03_widening_assign().
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,7 +19,7 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl_test.hh"
 #include <vector>
@@ -120,7 +120,7 @@ aux2_test01(unsigned n) {
 }
 
 void
-aux3_test01(std::ostream& s, const Variable& v) {
+aux3_test01(std::ostream& s, const Variable v) {
   s << char('x' + v.id());
 }
 
@@ -148,7 +148,7 @@ test01() {
     if (Sn.definitely_entails(T))
       converged = true;
     else
-      std::swap(Sn, T);
+      swap(Sn, T);
   }
 
   return converged;
@@ -350,7 +350,7 @@ aux2_test04(unsigned n) {
 }
 
 void
-aux3_test04(std::ostream& s, const Variable& v) {
+aux3_test04(std::ostream& s, const Variable v) {
   s << char('x' + v.id());
 }
 
@@ -378,7 +378,7 @@ test04() {
     if (Sn.definitely_entails(T))
       converged = true;
     else
-      std::swap(Sn, T);
+      swap(Sn, T);
   }
 
   return converged;
