@@ -1,6 +1,6 @@
 /* Test the allocation error recovery facility of the library.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,7 +19,7 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl_test.hh"
 #include <new>
@@ -150,7 +150,7 @@ test1() {
 
   reset_allocators(6, ULONG_MAX);
   try {
-    Matrix* matrix = new Matrix(2, 5);
+    Dense_Matrix* matrix = new Dense_Matrix(2, 5);
     // We will get here only if no exception is thrown:
     // this happens when using native coefficients.
     delete matrix;
