@@ -1,6 +1,6 @@
 /* Test the weightwatch (i.e., deterministic timeout) facility of the library.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,16 +19,15 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://www.cs.unipr.it/ppl/ . */
+site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl_test.hh"
-#include "pwl.hh"
 #include <stdexcept>
 
 namespace {
 
 typedef
-Parma_Watchdog_Library::Threshold_Watcher<Weightwatch_Traits> Weightwatch;
+Parma_Polyhedra_Library::Threshold_Watcher<Weightwatch_Traits> Weightwatch;
 
 class Deterministic_Timeout
   : virtual public std::exception,
@@ -101,7 +100,7 @@ bool test01() {
   print_constraints(ph, "*** ph ***");
 
   try {
-    Weightwatch ww(2500000, too_fat);
+    Weightwatch ww(5000000, too_fat);
     // Thanks to the blind relaxation of the strict inequality constraint,
     // polyhedron ph is easily seen to contain an integer point.
     const bool contains = ph.contains_integer_point();
